Module: OpenTelemetry::SemConv::DB
- Defined in:
- lib/opentelemetry/semconv/db/metrics.rb,
lib/opentelemetry/semconv/db/attributes.rb
Metrics Names collapse
- DB_CLIENT_OPERATION_DURATION =
Note:
Stability Level: stable
Duration of database client operations.
Batch operations SHOULD be recorded as a single operation.
'db.client.operation.duration'
Attribute Names collapse
- DB_COLLECTION_NAME =
Note:
Stability Level: stable
The name of a collection (table, container) within the database.
It is RECOMMENDED to capture the value as provided by the application without attempting to do any case normalization.
The collection name SHOULD NOT be extracted from
db.query.text, when the database system supports query text with multiple collections in non-batch operations.For batch operations, if the individual operations are known to have the same collection name then that collection name SHOULD be used.
'db.collection.name'- DB_NAMESPACE =
Note:
Stability Level: stable
The name of the database, fully qualified within the server address and port.
If a database system has multiple namespace components, they SHOULD be concatenated from the most general to the most specific namespace component, using
|as a separator between the components. Any missing components (and their associated separators) SHOULD be omitted. Semantic conventions for individual database systems SHOULD document whatdb.namespacemeans in the context of that system. It is RECOMMENDED to capture the value as provided by the application without attempting to do any case normalization. 'db.namespace'- DB_OPERATION_BATCH_SIZE =
Note:
Stability Level: stable
The number of database operations included in a batch operation.
Except for empty batch requests described below, a batch operation contains two or more database operations explicitly submitted as separate operations in a single client call, protocol message, or database command.
Requests to batch APIs that contain only one operation SHOULD be modeled as single operations, not as batch operations.
A database call is not a batch operation solely because one operation accepts multiple operands, such as keys, rows, documents, points, or other data elements, including Redis
MGETwith multiple keys.In batch APIs that execute the same parameterized operation with parameter sets, each parameter set represents one database operation for determining whether the request is a batch operation. Requests with only one parameter set SHOULD be modeled as single operations, not as batch operations.
db.operation.batch.sizeSHOULD be set to the number of operations in the batch. It SHOULD NOT be set for non-batch operations.A request to execute a batch operation with no operations SHOULD also be treated as a batch operation, and
db.operation.batch.sizeSHOULD be set to0. 'db.operation.batch.size'- DB_OPERATION_NAME =
Note:
Stability Level: stable
The name of the operation or command being executed.
It is RECOMMENDED to capture the value as provided by the application without attempting to do any case normalization.
The operation name SHOULD NOT be extracted from
db.query.text, when the database system supports query text with multiple operations in non-batch operations.If spaces can occur in the operation name, multiple consecutive spaces SHOULD be normalized to a single space.
For batch operations, if the individual operations are known to have the same operation name then that operation name SHOULD be used prepended by
BATCH, otherwisedb.operation.nameSHOULD beBATCHor some other database system specific term if more applicable. 'db.operation.name'- DB_QUERY_SUMMARY =
Note:
Stability Level: stable
Low cardinality summary of a database query.
The query summary describes a class of database queries and is useful as a grouping key, especially when analyzing telemetry for database calls involving complex queries.
Summary may be available to the instrumentation through instrumentation hooks or other means. If it is not available, instrumentations that support query parsing SHOULD generate a summary following Generating query summary section.
For batch operations, if the individual operations are known to have the same query summary then that query summary SHOULD be used prepended by
BATCH, otherwisedb.query.summarySHOULD beBATCHor some other database system specific term if more applicable. 'db.query.summary'- DB_QUERY_TEXT =
Note:
Stability Level: stable
The database query being executed.
For sanitization see Sanitization of
db.query.text. For batch operations, if the individual operations are known to have the same query text then that query text SHOULD be used, otherwise all of the individual query texts SHOULD be concatenated with separator;or some other database system specific separator if more applicable. Parameterized query text SHOULD NOT be sanitized. Even though parameterized query text can potentially have sensitive data, by using a parameterized query the user is giving a strong signal that any sensitive data will be passed as parameter values, and the benefit to observability of capturing the static part of the query text by default outweighs the risk. 'db.query.text'- DB_RESPONSE_STATUS_CODE =
Note:
Stability Level: stable
Database response status code.
The status code returned by the database. Usually it represents an error code, but may also represent partial success, warning, or differentiate between various types of successful outcomes. Semantic conventions for individual database systems SHOULD document what
db.response.status_codemeans in the context of that system. 'db.response.status_code'- DB_STORED_PROCEDURE_NAME =
Note:
Stability Level: stable
The name of a stored procedure within the database.
It is RECOMMENDED to capture the value as provided by the application without attempting to do any case normalization.
For batch operations, if the individual operations are known to have the same stored procedure name then that stored procedure name SHOULD be used.
'db.stored_procedure.name'- DB_SYSTEM_NAME =
Note:
Stability Level: stable
The database management system (DBMS) product as identified by the client instrumentation.
The actual DBMS may differ from the one identified by the client. For example, when using PostgreSQL client libraries to connect to a CockroachDB, the
db.system.nameis set topostgresqlbased on the instrumentation's best knowledge. 'db.system.name'