Module: OpenTelemetry::SemConv::DEPLOYMENT

Defined in:
lib/opentelemetry/semconv/deployment/attributes.rb

Attribute Names collapse

DEPLOYMENT_ENVIRONMENT_NAME =
Note:

Stability Level: stable

Name of the deployment environment (aka deployment tier).

deployment.environment.name does not affect the uniqueness constraints defined through the service.namespace, service.name and service.instance.id resource attributes. This implies that resources carrying the following attribute combinations MUST be considered to be identifying the same service:

  • service.name=frontend, deployment.environment.name=production
  • service.name=frontend, deployment.environment.name=staging.
'deployment.environment.name'