Module: OpenTelemetry::SemConv::Incubating::ANDROID

Defined in:
lib/opentelemetry/semconv/incubating/android/attributes.rb

Attribute Names collapse

ANDROID_APP_STATE =
Note:

Stability Level: development

This attribute represents the state of the application.

The Android lifecycle states are defined in Activity lifecycle callbacks, and from which the OS identifiers are derived.

'android.app.state'
ANDROID_OS_API_LEVEL =
Note:

Stability Level: development

Uniquely identifies the framework API revision offered by a version (os.version) of the android operating system. More information can be found in the Android API levels documentation.

'android.os.api_level'
ANDROID_STATE =
Deprecated.

Replaced by android.app.state.

Note:

Stability Level: development

Deprecated. Use android.app.state attribute instead.

'android.state'