Module: OpenTelemetry::SemConv::Incubating::APP

Defined in:
lib/opentelemetry/semconv/incubating/app/attributes.rb

Attribute Names collapse

APP_BUILD_ID =
Note:

Stability Level: development

Unique identifier for a particular build or compilation of the application.

'app.build_id'
APP_INSTALLATION_ID =
Note:

Stability Level: development

A unique identifier representing the installation of an application on a specific device

Its value SHOULD persist across launches of the same application installation, including through application upgrades. It SHOULD change if the application is uninstalled or if all applications of the vendor are uninstalled. Additionally, users might be able to reset this value (e.g. by clearing application data). If an app is installed multiple times on the same device (e.g. in different accounts on Android), each app.installation.id SHOULD have a different value. If multiple OpenTelemetry SDKs are used within the same application, they SHOULD use the same value for app.installation.id. Hardware IDs (e.g. serial number, IMEI, MAC address) MUST NOT be used as the app.installation.id.

For iOS, this value SHOULD be equal to the vendor identifier.

For Android, examples of app.installation.id implementations include:

More information about Android identifier best practices can be found in the Android user data IDs guide.

'app.installation.id'
APP_JANK_FRAME_COUNT =
Note:

Stability Level: development

A number of frame renders that experienced jank.

Depending on platform limitations, the value provided MAY be approximation.

'app.jank.frame_count'
APP_JANK_PERIOD =
Note:

Stability Level: development

The time period, in seconds, for which this jank is being reported.

'app.jank.period'
APP_JANK_THRESHOLD =
Note:

Stability Level: development

The minimum rendering threshold for this jank, in seconds.

'app.jank.threshold'
APP_SCREEN_COORDINATE_X =
Note:

Stability Level: development

The x (horizontal) coordinate of a screen coordinate, in screen pixels.

'app.screen.coordinate.x'
APP_SCREEN_COORDINATE_Y =
Note:

Stability Level: development

The y (vertical) component of a screen coordinate, in screen pixels.

'app.screen.coordinate.y'
APP_SCREEN_ID =
Note:

Stability Level: development

An identifier that uniquely differentiates this screen from other screens in the same application.

A screen represents only the part of the device display drawn by the app. It typically contains multiple widgets or UI components and is larger in scope than individual widgets. Multiple screens can coexist on the same display simultaneously (e.g., split view on tablets).

'app.screen.id'
APP_SCREEN_NAME =
Note:

Stability Level: development

The name of an application screen.

A screen represents only the part of the device display drawn by the app. It typically contains multiple widgets or UI components and is larger in scope than individual widgets. Multiple screens can coexist on the same display simultaneously (e.g., split view on tablets).

'app.screen.name'
APP_WIDGET_ID =
Note:

Stability Level: development

An identifier that uniquely differentiates this widget from other widgets in the same application.

A widget is an application component, typically an on-screen visual GUI element.

'app.widget.id'
APP_WIDGET_NAME =
Note:

Stability Level: development

The name of an application widget.

A widget is an application component, typically an on-screen visual GUI element.

'app.widget.name'