Module: OpenTelemetry::SemConv::Incubating::AWS

Defined in:
lib/opentelemetry/semconv/incubating/aws/attributes.rb

Attribute Names collapse

AWS_BEDROCK_GUARDRAIL_ID =
Note:

Stability Level: development

The unique identifier of the AWS Bedrock Guardrail. A guardrail helps safeguard and prevent unwanted behavior from model responses or user messages.

'aws.bedrock.guardrail.id'
AWS_BEDROCK_KNOWLEDGE_BASE_ID =
Note:

Stability Level: development

The unique identifier of the AWS Bedrock Knowledge base. A knowledge base is a bank of information that can be queried by models to generate more relevant responses and augment prompts.

'aws.bedrock.knowledge_base.id'
AWS_DYNAMODB_ATTRIBUTE_DEFINITIONS =
Note:

Stability Level: development

The JSON-serialized value of each item in the AttributeDefinitions request field.

'aws.dynamodb.attribute_definitions'
AWS_DYNAMODB_ATTRIBUTES_TO_GET =
Note:

Stability Level: development

The value of the AttributesToGet request parameter.

'aws.dynamodb.attributes_to_get'
AWS_DYNAMODB_CONSISTENT_READ =
Note:

Stability Level: development

The value of the ConsistentRead request parameter.

'aws.dynamodb.consistent_read'
AWS_DYNAMODB_CONSUMED_CAPACITY =
Note:

Stability Level: development

The JSON-serialized value of each item in the ConsumedCapacity response field.

'aws.dynamodb.consumed_capacity'
AWS_DYNAMODB_COUNT =
Note:

Stability Level: development

The value of the Count response parameter.

'aws.dynamodb.count'
AWS_DYNAMODB_EXCLUSIVE_START_TABLE =
Note:

Stability Level: development

The value of the ExclusiveStartTableName request parameter.

'aws.dynamodb.exclusive_start_table'
AWS_DYNAMODB_GLOBAL_SECONDARY_INDEX_UPDATES =
Note:

Stability Level: development

The JSON-serialized value of each item in the GlobalSecondaryIndexUpdates request field.

'aws.dynamodb.global_secondary_index_updates'
AWS_DYNAMODB_GLOBAL_SECONDARY_INDEXES =
Note:

Stability Level: development

The JSON-serialized value of each item of the GlobalSecondaryIndexes request field

'aws.dynamodb.global_secondary_indexes'
AWS_DYNAMODB_INDEX_NAME =
Note:

Stability Level: development

The value of the IndexName request parameter.

'aws.dynamodb.index_name'
AWS_DYNAMODB_ITEM_COLLECTION_METRICS =
Note:

Stability Level: development

The JSON-serialized value of the ItemCollectionMetrics response field.

'aws.dynamodb.item_collection_metrics'
AWS_DYNAMODB_LIMIT =
Note:

Stability Level: development

The value of the Limit request parameter.

'aws.dynamodb.limit'
AWS_DYNAMODB_LOCAL_SECONDARY_INDEXES =
Note:

Stability Level: development

The JSON-serialized value of each item of the LocalSecondaryIndexes request field.

'aws.dynamodb.local_secondary_indexes'
AWS_DYNAMODB_PROJECTION =
Note:

Stability Level: development

The value of the ProjectionExpression request parameter.

'aws.dynamodb.projection'
AWS_DYNAMODB_PROVISIONED_READ_CAPACITY =
Note:

Stability Level: development

The value of the ProvisionedThroughput.ReadCapacityUnits request parameter.

'aws.dynamodb.provisioned_read_capacity'
AWS_DYNAMODB_PROVISIONED_WRITE_CAPACITY =
Note:

Stability Level: development

The value of the ProvisionedThroughput.WriteCapacityUnits request parameter.

'aws.dynamodb.provisioned_write_capacity'
AWS_DYNAMODB_SCAN_FORWARD =
Note:

Stability Level: development

The value of the ScanIndexForward request parameter.

'aws.dynamodb.scan_forward'
AWS_DYNAMODB_SCANNED_COUNT =
Note:

Stability Level: development

The value of the ScannedCount response parameter.

'aws.dynamodb.scanned_count'
AWS_DYNAMODB_SEGMENT =
Note:

Stability Level: development

The value of the Segment request parameter.

'aws.dynamodb.segment'
AWS_DYNAMODB_SELECT =
Note:

Stability Level: development

The value of the Select request parameter.

'aws.dynamodb.select'
AWS_DYNAMODB_TABLE_COUNT =
Note:

Stability Level: development

The number of items in the TableNames response parameter.

'aws.dynamodb.table_count'
AWS_DYNAMODB_TABLE_NAMES =
Note:

Stability Level: development

The keys in the RequestItems object field.

'aws.dynamodb.table_names'
AWS_DYNAMODB_TOTAL_SEGMENTS =
Note:

Stability Level: development

The value of the TotalSegments request parameter.

'aws.dynamodb.total_segments'
AWS_ECS_CLUSTER_ARN =
Note:

Stability Level: development

The ARN of an ECS cluster.

'aws.ecs.cluster.arn'
AWS_ECS_CONTAINER_ARN =
Note:

Stability Level: development

The Amazon Resource Name (ARN) of an ECS container instance.

'aws.ecs.container.arn'
AWS_ECS_LAUNCHTYPE =
Note:

Stability Level: development

The launch type for an ECS task.

'aws.ecs.launchtype'
AWS_ECS_TASK_ARN =
Note:

Stability Level: development

The ARN of a running ECS task.

'aws.ecs.task.arn'
AWS_ECS_TASK_FAMILY =
Note:

Stability Level: development

The family name of the ECS task definition used to create the ECS task.

'aws.ecs.task.family'
AWS_ECS_TASK_ID =
Note:

Stability Level: development

The ID of a running ECS task. The ID MUST be extracted from task.arn.

'aws.ecs.task.id'
AWS_ECS_TASK_REVISION =
Note:

Stability Level: development

The revision for the task definition used to create the ECS task.

'aws.ecs.task.revision'
AWS_EKS_CLUSTER_ARN =
Note:

Stability Level: development

The ARN of an EKS cluster.

'aws.eks.cluster.arn'
AWS_EXTENDED_REQUEST_ID =
Note:

Stability Level: development

The AWS extended request ID as returned in the response header x-amz-id-2.

'aws.extended_request_id'
AWS_KINESIS_STREAM_NAME =
Note:

Stability Level: development

The name of the AWS Kinesis stream the request refers to. Corresponds to the --stream-name parameter of the Kinesis describe-stream operation.

'aws.kinesis.stream_name'
AWS_LAMBDA_INVOKED_ARN =
Note:

Stability Level: development

The full invoked ARN as provided on the Context passed to the function (Lambda-Runtime-Invoked-Function-Arn header on the /runtime/invocation/next applicable).

This may be different from cloud.resource_id if an alias is involved.

'aws.lambda.invoked_arn'
AWS_LAMBDA_RESOURCE_MAPPING_ID =
Note:

Stability Level: development

The UUID of the AWS Lambda EvenSource Mapping. An event source is mapped to a lambda function. It's contents are read by Lambda and used to trigger a function. This isn't available in the lambda execution context or the lambda runtime environtment. This is going to be populated by the AWS SDK for each language when that UUID is present. Some of these operations are Create/Delete/Get/List/Update EventSourceMapping.

'aws.lambda.resource_mapping.id'
AWS_LOG_GROUP_ARNS =
Note:

Stability Level: development

The Amazon Resource Name(s) (ARN) of the AWS log group(s).

See the log group ARN format documentation.

'aws.log.group.arns'
AWS_LOG_GROUP_NAMES =
Note:

Stability Level: development

The name(s) of the AWS log group(s) an application is writing to.

Multiple log groups must be supported for cases like multi-container applications, where a single application has sidecar containers, and each write to their own log group.

'aws.log.group.names'
AWS_LOG_STREAM_ARNS =
Note:

Stability Level: development

The ARN(s) of the AWS log stream(s).

See the log stream ARN format documentation. One log group can contain several log streams, so these ARNs necessarily identify both a log group and a log stream.

'aws.log.stream.arns'
AWS_LOG_STREAM_NAMES =
Note:

Stability Level: development

The name(s) of the AWS log stream(s) an application is writing to.

'aws.log.stream.names'
AWS_REQUEST_ID =
Note:

Stability Level: development

The AWS request ID as returned in the response headers x-amzn-requestid, x-amzn-request-id or x-amz-request-id.

'aws.request_id'
AWS_S3_BUCKET =
Note:

Stability Level: development

The S3 bucket name the request refers to. Corresponds to the --bucket parameter of the S3 API operations.

The bucket attribute is applicable to all S3 operations that reference a bucket, i.e. that require the bucket name as a mandatory parameter. This applies to almost all S3 operations except list-buckets.

'aws.s3.bucket'
AWS_S3_COPY_SOURCE =
Note:

Stability Level: development

The source object (in the form bucket/key) for the copy operation.

The copy_source attribute applies to S3 copy operations and corresponds to the --copy-source parameter of the copy-object operation within the S3 API. This applies in particular to the following operations:

'aws.s3.copy_source'
AWS_S3_DELETE =
Note:

Stability Level: development

The delete request container that specifies the objects to be deleted.

The delete attribute is only applicable to the delete-object operation. The delete attribute corresponds to the --delete parameter of the delete-objects operation within the S3 API.

'aws.s3.delete'
AWS_S3_KEY =
Note:

Stability Level: development

The S3 object key the request refers to. Corresponds to the --key parameter of the S3 API operations.

The key attribute is applicable to all object-related S3 operations, i.e. that require the object key as a mandatory parameter. This applies in particular to the following operations:

'aws.s3.key'
AWS_S3_PART_NUMBER =
Note:

Stability Level: development

The part number of the part being uploaded in a multipart-upload operation. This is a positive integer between 1 and 10,000.

The part_number attribute is only applicable to the upload-part and upload-part-copy operations. The part_number attribute corresponds to the --part-number parameter of the upload-part operation within the S3 API.

'aws.s3.part_number'
AWS_S3_UPLOAD_ID =
Note:

Stability Level: development

Upload ID that identifies the multipart upload.

The upload_id attribute applies to S3 multipart-upload operations and corresponds to the --upload-id parameter of the S3 API multipart operations. This applies in particular to the following operations:

'aws.s3.upload_id'
AWS_SECRETSMANAGER_SECRET_ARN =
Note:

Stability Level: development

The ARN of the Secret stored in the Secrets Mangger

'aws.secretsmanager.secret.arn'
AWS_SNS_TOPIC_ARN =
Note:

Stability Level: development

The ARN of the AWS SNS Topic. An Amazon SNS topic is a logical access point that acts as a communication channel.

'aws.sns.topic.arn'
AWS_SQS_QUEUE_URL =
Note:

Stability Level: development

The URL of the AWS SQS Queue. It's a unique identifier for a queue in Amazon Simple Queue Service (SQS) and is used to access the queue and perform actions on it.

'aws.sqs.queue.url'
AWS_STEP_FUNCTIONS_ACTIVITY_ARN =
Note:

Stability Level: development

The ARN of the AWS Step Functions Activity.

'aws.step_functions.activity.arn'
AWS_STEP_FUNCTIONS_STATE_MACHINE_ARN =
Note:

Stability Level: development

The ARN of the AWS Step Functions State Machine.

'aws.step_functions.state_machine.arn'