Module: OpenTelemetry::SemConv::Incubating::AZURE

Defined in:
lib/opentelemetry/semconv/incubating/azure/metrics.rb,
lib/opentelemetry/semconv/incubating/azure/attributes.rb

Metrics Names collapse

AZURE_COSMOSDB_CLIENT_ACTIVE_INSTANCE_COUNT =
Note:

Stability Level: development

Number of active client instances.

'azure.cosmosdb.client.active_instance.count'
AZURE_COSMOSDB_CLIENT_OPERATION_REQUEST_CHARGE =
Note:

Stability Level: development

Request units consumed by the operation.

'azure.cosmosdb.client.operation.request_charge'

Attribute Names collapse

AZURE_CLIENT_ID =
Note:

Stability Level: development

The unique identifier of the client instance.

'azure.client.id'
AZURE_COSMOSDB_CONNECTION_MODE =
Note:

Stability Level: development

Cosmos client connection mode.

'azure.cosmosdb.connection.mode'
AZURE_COSMOSDB_CONSISTENCY_LEVEL =
Note:

Stability Level: development

Account or request consistency level.

'azure.cosmosdb.consistency.level'
AZURE_COSMOSDB_OPERATION_CONTACTED_REGIONS =
Note:

Stability Level: development

List of regions contacted during operation in the order that they were contacted. If there is more than one region listed, it indicates that the operation was performed on multiple regions i.e. cross-regional call.

Region name matches the format of displayName in Azure Location API

'azure.cosmosdb.operation.contacted_regions'
AZURE_COSMOSDB_OPERATION_REQUEST_CHARGE =
Note:

Stability Level: development

The number of request units consumed by the operation.

'azure.cosmosdb.operation.request_charge'
AZURE_COSMOSDB_REQUEST_BODY_SIZE =
Note:

Stability Level: development

Request payload size in bytes.

'azure.cosmosdb.request.body.size'
AZURE_COSMOSDB_RESPONSE_SUB_STATUS_CODE =
Note:

Stability Level: development

Cosmos DB sub status code.

'azure.cosmosdb.response.sub_status_code'
AZURE_RESOURCE_PROVIDER_NAMESPACE =
Note:

Stability Level: development

Azure Resource Provider Namespace as recognized by the client.

'azure.resource_provider.namespace'
AZURE_SERVICE_REQUEST_ID =
Note:

Stability Level: development

The unique identifier of the service request. It's generated by the Azure service and returned with the response.

'azure.service.request.id'