Module: OpenTelemetry::SemConv::Incubating::BROWSER
- Defined in:
- lib/opentelemetry/semconv/incubating/browser/attributes.rb
Attribute Names collapse
- BROWSER_BRANDS =
Note:
Stability Level: development
Array of brand name and version separated by a space
This value is intended to be taken from the UA client hints API (
navigator.userAgentData.brands). 'browser.brands'- BROWSER_DOCUMENT_URL_FULL =
Note:
Stability Level: development
Absolute URL of the current browser document according to RFC3986.
'browser.document.url.full'- BROWSER_LANGUAGE =
Note:
Stability Level: development
Preferred language of the user using the browser
This value is intended to be taken from the Navigator API
navigator.language. 'browser.language'- BROWSER_MOBILE =
Note:
Stability Level: development
A boolean that is true if the browser is running on a mobile device
This value is intended to be taken from the UA client hints API (
navigator.userAgentData.mobile). If unavailable, this attribute SHOULD be left unset. 'browser.mobile'- BROWSER_PLATFORM =
Note:
Stability Level: development
The platform on which the browser is running
This value is intended to be taken from the UA client hints API (
navigator.userAgentData.platform). If unavailable, the legacynavigator.platformAPI SHOULD NOT be used instead and this attribute SHOULD be left unset in order for the values to be consistent. The list of possible values is defined in the W3C User-Agent Client Hints specification. Note that some (but not all) of these values can overlap with values in theos.typeandos.nameattributes. However, for consistency, the values in thebrowser.platformattribute should capture the exact value that the user agent provides. 'browser.platform'- BROWSER_WEB_VITAL_DELTA =
Note:
Stability Level: development
The delta between the current value and the last-reported value. See delta.
'browser.web_vital.delta'- BROWSER_WEB_VITAL_ID =
Note:
Stability Level: development
A unique ID representing this particular metric instance.
'browser.web_vital.id'- BROWSER_WEB_VITAL_NAME =
Note:
Stability Level: development
Name of the web vital.
'browser.web_vital.name'- BROWSER_WEB_VITAL_NAVIGATION_TYPE =
Note:
Stability Level: development
The type of navigation, as reported by the Navigation Timing API, with additional values reported by the web-vitals library.
'browser.web_vital.navigation_type'- BROWSER_WEB_VITAL_RATING =
Note:
Stability Level: development
The rating of the web vital value against the "good", "needs improvement", and "poor" thresholds defined for the metric.
'browser.web_vital.rating'- BROWSER_WEB_VITAL_VALUE =
Note:
Stability Level: development
Value of the web vital.
'browser.web_vital.value'