Module: OpenTelemetry::SemConv::Incubating::CASSANDRA

Defined in:
lib/opentelemetry/semconv/incubating/cassandra/attributes.rb

Attribute Names collapse

CASSANDRA_CONSISTENCY_LEVEL =
Note:

Stability Level: development

The consistency level of the query. Based on consistency values from CQL.

'cassandra.consistency.level'
CASSANDRA_COORDINATOR_DC =
Note:

Stability Level: development

The data center of the coordinating node for a query.

'cassandra.coordinator.dc'
CASSANDRA_COORDINATOR_ID =
Note:

Stability Level: development

The ID of the coordinating node for a query.

'cassandra.coordinator.id'
CASSANDRA_PAGE_SIZE =
Note:

Stability Level: development

The fetch size used for paging, i.e. how many rows will be returned at once.

'cassandra.page.size'
CASSANDRA_QUERY_IDEMPOTENT =
Note:

Stability Level: development

Whether or not the query is idempotent.

'cassandra.query.idempotent'
CASSANDRA_SPECULATIVE_EXECUTION_COUNT =
Note:

Stability Level: development

The number of times a query was speculatively executed. Not set or 0 if the query was not executed speculatively.

'cassandra.speculative_execution.count'