Module: OpenTelemetry::SemConv::Incubating::CLOUDEVENTS

Defined in:
lib/opentelemetry/semconv/incubating/cloudevents/attributes.rb

Attribute Names collapse

CLOUDEVENTS_EVENT_ID =
Note:

Stability Level: development

The event_id uniquely identifies the event.

'cloudevents.event_id'
CLOUDEVENTS_EVENT_SOURCE =
Note:

Stability Level: development

The source identifies the context in which an event happened.

'cloudevents.event_source'
CLOUDEVENTS_EVENT_SPEC_VERSION =
Note:

Stability Level: development

The version of the CloudEvents specification which the event uses.

'cloudevents.event_spec_version'
CLOUDEVENTS_EVENT_SUBJECT =
Note:

Stability Level: development

The subject of the event in the context of the event producer (identified by source).

'cloudevents.event_subject'
CLOUDEVENTS_EVENT_TYPE =
Note:

Stability Level: development

The event_type contains a value describing the type of event related to the originating occurrence.

'cloudevents.event_type'