Module: OpenTelemetry::SemConv::Incubating::CLOUDFOUNDRY

Defined in:
lib/opentelemetry/semconv/incubating/cloudfoundry/attributes.rb

Attribute Names collapse

CLOUDFOUNDRY_APP_ID =
Note:

Stability Level: development

The guid of the application.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.application_id. This is the same value as reported by cf app <app-name> --guid.

'cloudfoundry.app.id'
CLOUDFOUNDRY_APP_INSTANCE_ID =
Note:

Stability Level: development

The index of the application instance. 0 when just one instance is active.

CloudFoundry defines the instance_id in the Loggregator v2 envelope. It is used for logs and metrics emitted by CloudFoundry. It is supposed to contain the application instance index for applications deployed on the runtime.

Application instrumentation should use the value from environment variable CF_INSTANCE_INDEX.

'cloudfoundry.app.instance.id'
CLOUDFOUNDRY_APP_NAME =
Note:

Stability Level: development

The name of the application.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.application_name. This is the same value as reported by cf apps.

'cloudfoundry.app.name'
CLOUDFOUNDRY_ORG_ID =
Note:

Stability Level: development

The guid of the CloudFoundry org the application is running in.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.org_id. This is the same value as reported by cf org <org-name> --guid.

'cloudfoundry.org.id'
CLOUDFOUNDRY_ORG_NAME =
Note:

Stability Level: development

The name of the CloudFoundry organization the app is running in.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.org_name. This is the same value as reported by cf orgs.

'cloudfoundry.org.name'
CLOUDFOUNDRY_PROCESS_ID =
Note:

Stability Level: development

The UID identifying the process.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.process_id. It is supposed to be equal to VCAP_APPLICATION.app_id for applications deployed to the runtime. For system components, this could be the actual PID.

'cloudfoundry.process.id'
CLOUDFOUNDRY_PROCESS_TYPE =
Note:

Stability Level: development

The type of process.

CloudFoundry applications can consist of multiple jobs. Usually the main process will be of type web. There can be additional background tasks or side-cars with different process types.

'cloudfoundry.process.type'
CLOUDFOUNDRY_SPACE_ID =
Note:

Stability Level: development

The guid of the CloudFoundry space the application is running in.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.space_id. This is the same value as reported by cf space <space-name> --guid.

'cloudfoundry.space.id'
CLOUDFOUNDRY_SPACE_NAME =
Note:

Stability Level: development

The name of the CloudFoundry space the application is running in.

Application instrumentation should use the value from environment variable VCAP_APPLICATION.space_name. This is the same value as reported by cf spaces.

'cloudfoundry.space.name'
CLOUDFOUNDRY_SYSTEM_ID =
Note:

Stability Level: development

A guid or another name describing the event source.

CloudFoundry defines the source_id in the Loggregator v2 envelope. It is used for logs and metrics emitted by CloudFoundry. It is supposed to contain the component name, e.g. "gorouter", for CloudFoundry components.

When system components are instrumented, values from the Bosh spec should be used. The system.id should be set to spec.deployment/spec.name.

'cloudfoundry.system.id'
CLOUDFOUNDRY_SYSTEM_INSTANCE_ID =
Note:

Stability Level: development

A guid describing the concrete instance of the event source.

CloudFoundry defines the instance_id in the Loggregator v2 envelope. It is used for logs and metrics emitted by CloudFoundry. It is supposed to contain the vm id for CloudFoundry components.

When system components are instrumented, values from the Bosh spec should be used. The system.instance.id should be set to spec.id.

'cloudfoundry.system.instance.id'