Module: OpenTelemetry::SemConv::Incubating::CODE

Defined in:
lib/opentelemetry/semconv/incubating/code/attributes.rb

Attribute Names collapse

CODE_COLUMN =
Deprecated.

Replaced by code.column.number.

Note:

Stability Level: development

Deprecated, use code.column.number

'code.column'
CODE_COLUMN_NUMBER =
Deprecated.

Now available in the stable namespace at CODE::CODE_COLUMN_NUMBER.

Note:

Stability Level: stable

The column number in code.file.path best representing the operation. It SHOULD point within the code unit named in code.function.name. This attribute MUST NOT be used on the Profile signal since the data is already captured in 'message Line'. This constraint is imposed to prevent redundancy and maintain data integrity.

'code.column.number'
CODE_FILE_PATH =
Deprecated.

Now available in the stable namespace at CODE::CODE_FILE_PATH.

Note:

Stability Level: stable

The source code file name that identifies the code unit as uniquely as possible (preferably an absolute file path). This attribute MUST NOT be used on the Profile signal since the data is already captured in 'message Function'. This constraint is imposed to prevent redundancy and maintain data integrity.

'code.file.path'
CODE_FILEPATH =
Deprecated.

Replaced by code.file.path.

Note:

Stability Level: development

Deprecated, use code.file.path instead

'code.filepath'
CODE_FUNCTION =
Deprecated.

Value should be included in code.function.name which is expected to be a fully-qualified name.

Note:

Stability Level: development

Deprecated, use code.function.name instead

'code.function'
CODE_FUNCTION_NAME =
Deprecated.

Now available in the stable namespace at CODE::CODE_FUNCTION_NAME.

Note:

Stability Level: stable

The method or function fully-qualified name without arguments. The value should fit the natural representation of the language runtime, which is also likely the same used within code.stacktrace attribute value. This attribute MUST NOT be used on the Profile signal since the data is already captured in 'message Function'. This constraint is imposed to prevent redundancy and maintain data integrity.

Values and format depends on each language runtime, thus it is impossible to provide an exhaustive list of examples. The values are usually the same (or prefixes of) the ones found in native stack trace representation stored in code.stacktrace without information on arguments.

Examples:

  • Java method: com.example.MyHttpService.serveRequest
  • Java anonymous class method: com.mycompany.Main$1.myMethod
  • Java lambda method: com.mycompany.Main$$Lambda/0x0000748ae4149c00.myMethod
  • PHP function: GuzzleHttp\Client::transfer
  • Go function: github.com/my/repo/pkg.foo.func5
  • Elixir: OpenTelemetry.Ctx.new
  • Erlang: opentelemetry_ctx:new
  • Rust: playground::my_module::my_cool_func
  • C function: fopen
'code.function.name'
CODE_LINE_NUMBER =
Deprecated.

Now available in the stable namespace at CODE::CODE_LINE_NUMBER.

Note:

Stability Level: stable

The line number in code.file.path best representing the operation. It SHOULD point within the code unit named in code.function.name. This attribute MUST NOT be used on the Profile signal since the data is already captured in 'message Line'. This constraint is imposed to prevent redundancy and maintain data integrity.

'code.line.number'
CODE_LINENO =
Deprecated.

Replaced by code.line.number.

Note:

Stability Level: development

Deprecated, use code.line.number instead

'code.lineno'
CODE_NAMESPACE =
Deprecated.

Value should be included in code.function.name which is expected to be a fully-qualified name.

Note:

Stability Level: development

Deprecated, namespace is now included into code.function.name

'code.namespace'
CODE_STACKTRACE =
Deprecated.

Now available in the stable namespace at CODE::CODE_STACKTRACE.

Note:

Stability Level: stable

A stacktrace as a string in the natural representation for the language runtime. The representation is identical to exception.stacktrace. This attribute MUST NOT be used on the Profile signal since the data is already captured in 'message Location'. This constraint is imposed to prevent redundancy and maintain data integrity.

'code.stacktrace'