Module: OpenTelemetry::SemConv::Incubating::DEPLOYMENT

Defined in:
lib/opentelemetry/semconv/incubating/deployment/attributes.rb

Attribute Names collapse

DEPLOYMENT_ENVIRONMENT =
Deprecated.

Replaced by deployment.environment.name.

Note:

Stability Level: development

Deprecated, use deployment.environment.name instead.

'deployment.environment'
DEPLOYMENT_ENVIRONMENT_NAME =
Note:

Stability Level: development

Name of the deployment environment (aka deployment tier).

deployment.environment.name does not affect the uniqueness constraints defined through the service.namespace, service.name and service.instance.id resource attributes. This implies that resources carrying the following attribute combinations MUST be considered to be identifying the same service:

  • service.name=frontend, deployment.environment.name=production
  • service.name=frontend, deployment.environment.name=staging.
'deployment.environment.name'
DEPLOYMENT_ID =
Note:

Stability Level: development

The id of the deployment.

'deployment.id'
DEPLOYMENT_NAME =
Note:

Stability Level: development

The name of the deployment.

'deployment.name'
DEPLOYMENT_STATUS =
Note:

Stability Level: development

The status of the deployment.

'deployment.status'