Module: OpenTelemetry::SemConv::Incubating::ENDUSER

Defined in:
lib/opentelemetry/semconv/incubating/enduser/attributes.rb

Attribute Names collapse

ENDUSER_ID =
Note:

Stability Level: development

Unique identifier of an end user in the system. It maybe a username, email address, or other identifier.

Unique identifier of an end user in the system.

[!Warning] This field contains sensitive (PII) information.

'enduser.id'
ENDUSER_PSEUDO_ID =
Note:

Stability Level: development

Pseudonymous identifier of an end user. This identifier should be a random value that is not directly linked or associated with the end user's actual identity.

Pseudonymous identifier of an end user.

[!Warning] This field contains sensitive (linkable PII) information.

'enduser.pseudo.id'
ENDUSER_ROLE =
Deprecated.

Use user.roles instead.

Note:

Stability Level: development

Deprecated, use user.roles instead.

'enduser.role'
ENDUSER_SCOPE =
Deprecated.

Removed, no replacement at this time.

Note:

Stability Level: development

Deprecated, no replacement at this time.

'enduser.scope'