Module: OpenTelemetry::SemConv::Incubating::EXCEPTION
- Defined in:
- lib/opentelemetry/semconv/incubating/exception/attributes.rb
Attribute Names collapse
- EXCEPTION_ESCAPED =
Deprecated.
It's no longer recommended to record exceptions that are handled and do not escape the scope of a span.
Note:Stability Level: stable
Indicates that the exception is escaping the scope of the span.
'exception.escaped'- EXCEPTION_MESSAGE =
Deprecated.
Now available in the stable namespace at EXCEPTION::EXCEPTION_MESSAGE.
Note:Stability Level: stable
The exception message.
[!WARNING]> This attribute may contain sensitive information.
'exception.message'- EXCEPTION_STACKTRACE =
Deprecated.
Now available in the stable namespace at EXCEPTION::EXCEPTION_STACKTRACE.
Note:Stability Level: stable
A stacktrace as a string in the natural representation for the language runtime. The representation is to be determined and documented by each language SIG.
'exception.stacktrace'- EXCEPTION_TYPE =
Deprecated.
Now available in the stable namespace at EXCEPTION::EXCEPTION_TYPE.
Note:Stability Level: stable
The type of the exception (its fully-qualified class name, if applicable). The dynamic type of the exception should be preferred over the static type in languages that support it.
If the recorded exception type is a wrapper that is not meaningful for failure classification, instrumentation MAY use the type of the inner exception instead. For example, in Go, errors created with
fmt.Errorfusing%wMAY be unwrapped when the wrapper type does not help classify the failure. 'exception.type'