Module: OpenTelemetry::SemConv::Incubating::FEATURE_FLAG

Defined in:
lib/opentelemetry/semconv/incubating/feature_flag/attributes.rb

Attribute Names collapse

FEATURE_FLAG_CONTEXT_ID =
Note:

Stability Level: release_candidate

The unique identifier for the flag evaluation context. For example, the targeting key.

'feature_flag.context.id'
FEATURE_FLAG_EVALUATION_ERROR_MESSAGE =
Deprecated.

Replaced by error.message.

Note:

Stability Level: development

Deprecated, use error.message instead.

'feature_flag.evaluation.error.message'
FEATURE_FLAG_EVALUATION_REASON =
Deprecated.

Replaced by feature_flag.result.reason.

Note:

Stability Level: development

Deprecated, use feature_flag.result.reason instead.

'feature_flag.evaluation.reason'
FEATURE_FLAG_KEY =
Note:

Stability Level: release_candidate

The lookup key of the feature flag.

'feature_flag.key'
FEATURE_FLAG_PROVIDER_NAME =
Note:

Stability Level: release_candidate

Identifies the feature flag provider.

'feature_flag.provider.name'
FEATURE_FLAG_RESULT_REASON =
Note:

Stability Level: release_candidate

The reason code which shows how a feature flag value was determined.

'feature_flag.result.reason'
FEATURE_FLAG_RESULT_VALUE =
Note:

Stability Level: release_candidate

The evaluated value of the feature flag.

With some feature flag providers, feature flag results can be quite large or contain private or sensitive details. Because of this, feature_flag.result.variant is often the preferred attribute if it is available.

It may be desirable to redact or otherwise limit the size and scope of feature_flag.result.value if possible. Because the evaluated flag value is unstructured and may be any type, it is left to the instrumentation author to determine how best to achieve this.

'feature_flag.result.value'
FEATURE_FLAG_RESULT_VARIANT =
Note:

Stability Level: release_candidate

A semantic identifier for an evaluated flag value.

A semantic identifier, commonly referred to as a variant, provides a means for referring to a value without including the value itself. This can provide additional context for understanding the meaning behind a value. For example, the variant red maybe be used for the value #c05543.

'feature_flag.result.variant'
FEATURE_FLAG_SET_ID =
Note:

Stability Level: release_candidate

The identifier of the flag set to which the feature flag belongs.

'feature_flag.set.id'
FEATURE_FLAG_VARIANT =
Deprecated.

Replaced by feature_flag.result.variant.

Note:

Stability Level: development

Deprecated, use feature_flag.result.variant instead.

'feature_flag.variant'
FEATURE_FLAG_VERSION =
Note:

Stability Level: release_candidate

The version of the ruleset used during the evaluation. This may be any stable value which uniquely identifies the ruleset.

'feature_flag.version'