Module: OpenTelemetry::SemConv::Incubating::GCP

Defined in:
lib/opentelemetry/semconv/incubating/gcp/attributes.rb

Attribute Names collapse

GCP_APPHUB_APPLICATION_CONTAINER =
Note:

Stability Level: development

The container within GCP where the AppHub application is defined.

'gcp.apphub.application.container'
GCP_APPHUB_APPLICATION_ID =
Note:

Stability Level: development

The name of the application as configured in AppHub.

'gcp.apphub.application.id'
GCP_APPHUB_APPLICATION_LOCATION =
Note:

Stability Level: development

The GCP zone or region where the application is defined.

'gcp.apphub.application.location'
GCP_APPHUB_SERVICE_CRITICALITY_TYPE =
Note:

Stability Level: development

Criticality of a service indicates its importance to the business.

See AppHub type enum

'gcp.apphub.service.criticality_type'
GCP_APPHUB_SERVICE_ENVIRONMENT_TYPE =
Note:

Stability Level: development

Environment of a service is the stage of a software lifecycle.

See AppHub environment type

'gcp.apphub.service.environment_type'
GCP_APPHUB_SERVICE_ID =
Note:

Stability Level: development

The name of the service as configured in AppHub.

'gcp.apphub.service.id'
GCP_APPHUB_WORKLOAD_CRITICALITY_TYPE =
Note:

Stability Level: development

Criticality of a workload indicates its importance to the business.

See AppHub type enum

'gcp.apphub.workload.criticality_type'
GCP_APPHUB_WORKLOAD_ENVIRONMENT_TYPE =
Note:

Stability Level: development

Environment of a workload is the stage of a software lifecycle.

See AppHub environment type

'gcp.apphub.workload.environment_type'
GCP_APPHUB_WORKLOAD_ID =
Note:

Stability Level: development

The name of the workload as configured in AppHub.

'gcp.apphub.workload.id'
GCP_APPHUB_DESTINATION_APPLICATION_CONTAINER =
Note:

Stability Level: development

The container within GCP where the AppHub destination application is defined.

'gcp.apphub_destination.application.container'
GCP_APPHUB_DESTINATION_APPLICATION_ID =
Note:

Stability Level: development

The name of the destination application as configured in AppHub.

'gcp.apphub_destination.application.id'
GCP_APPHUB_DESTINATION_APPLICATION_LOCATION =
Note:

Stability Level: development

The GCP zone or region where the destination application is defined.

'gcp.apphub_destination.application.location'
GCP_APPHUB_DESTINATION_SERVICE_CRITICALITY_TYPE =
Note:

Stability Level: development

Criticality of a destination workload indicates its importance to the business as specified in AppHub type enum

'gcp.apphub_destination.service.criticality_type'
GCP_APPHUB_DESTINATION_SERVICE_ENVIRONMENT_TYPE =
Note:

Stability Level: development

Software lifecycle stage of a destination service as defined AppHub environment type

'gcp.apphub_destination.service.environment_type'
GCP_APPHUB_DESTINATION_SERVICE_ID =
Note:

Stability Level: development

The name of the destination service as configured in AppHub.

'gcp.apphub_destination.service.id'
GCP_APPHUB_DESTINATION_WORKLOAD_CRITICALITY_TYPE =
Note:

Stability Level: development

Criticality of a destination workload indicates its importance to the business as specified in AppHub type enum

'gcp.apphub_destination.workload.criticality_type'
GCP_APPHUB_DESTINATION_WORKLOAD_ENVIRONMENT_TYPE =
Note:

Stability Level: development

Environment of a destination workload is the stage of a software lifecycle as provided in the AppHub environment type

'gcp.apphub_destination.workload.environment_type'
GCP_APPHUB_DESTINATION_WORKLOAD_ID =
Note:

Stability Level: development

The name of the destination workload as configured in AppHub.

'gcp.apphub_destination.workload.id'
GCP_CLIENT_SERVICE =
Note:

Stability Level: development

Identifies the Google Cloud service for which the official client library is intended.

Intended to be a stable identifier for Google Cloud client libraries that is uniform across implementation languages. The value should be derived from the canonical service domain for the service; for example, 'foo.googleapis.com' should result in a value of 'foo'.

'gcp.client.service'
GCP_CLOUD_RUN_JOB_EXECUTION =
Note:

Stability Level: development

The name of the Cloud Run execution being run for the Job, as set by the CLOUD_RUN_EXECUTION environment variable.

'gcp.cloud_run.job.execution'
GCP_CLOUD_RUN_JOB_TASK_INDEX =
Note:

Stability Level: development

The index for a task within an execution as provided by the CLOUD_RUN_TASK_INDEX environment variable.

'gcp.cloud_run.job.task_index'
GCP_GCE_INSTANCE_HOSTNAME =
Note:

Stability Level: development

The hostname of a GCE instance. This is the full value of the default or custom hostname.

'gcp.gce.instance.hostname'
GCP_GCE_INSTANCE_NAME =
Note:

Stability Level: development

The instance name of a GCE instance. This is the value provided by host.name, the visible name of the instance in the Cloud Console UI, and the prefix for the default hostname of the instance as defined by the default internal DNS name.

'gcp.gce.instance.name'