Module: OpenTelemetry::SemConv::Incubating::GO

Defined in:
lib/opentelemetry/semconv/incubating/go/metrics.rb,
lib/opentelemetry/semconv/incubating/go/attributes.rb

Metrics Names collapse

GO_CONFIG_GOGC =
Note:

Stability Level: development

Heap size target percentage configured by the user, otherwise 100.

The value range is [0.0,100.0]. Computed from /gc/gogc:percent.

'go.config.gogc'
GO_CPU_TIME =
Note:

Stability Level: development

Estimated CPU time spent by the Go runtime.

Computed from /cpu/classes/... metrics. This metric is an overestimate, and not directly comparable to system CPU time measurements. Compare only with other go.cpu.time metrics.

'go.cpu.time'
GO_GOROUTINE_COUNT =
Note:

Stability Level: development

Count of live goroutines.

Computed from /sched/goroutines:goroutines.

'go.goroutine.count'
GO_MEMORY_ALLOCATED =
Note:

Stability Level: development

Memory allocated to the heap by the application.

Computed from /gc/heap/allocs:bytes.

'go.memory.allocated'
GO_MEMORY_ALLOCATIONS =
Note:

Stability Level: development

Count of allocations to the heap by the application.

Computed from /gc/heap/allocs:objects.

'go.memory.allocations'
GO_MEMORY_GC_CYCLES =
Note:

Stability Level: development

Number of completed GC cycles.

Computed from /gc/cycles/total:gc-cycles.

'go.memory.gc.cycles'
GO_MEMORY_GC_GOAL =
Note:

Stability Level: development

Heap size target for the end of the GC cycle.

Computed from /gc/heap/goal:bytes.

'go.memory.gc.goal'
GO_MEMORY_GC_PAUSE_DURATION =
Note:

Stability Level: development

Distribution of individual GC-related stop-the-world pause latencies. This is the time from deciding to stop the world until the world is started again.

Computed from /sched/pauses/total/gc:seconds. Bucket boundaries are provided by the runtime, and are subject to change.

'go.memory.gc.pause.duration'
GO_MEMORY_LIMIT =
Note:

Stability Level: development

Go runtime memory limit configured by the user, if a limit exists.

Computed from /gc/gomemlimit:bytes. This metric is excluded if the limit obtained from the Go runtime is math.MaxInt64.

'go.memory.limit'
GO_MEMORY_USED =
Note:

Stability Level: development

Memory used by the Go runtime.

Computed from (/memory/classes/total:bytes - /memory/classes/heap/released:bytes).

'go.memory.used'
GO_PROCESSOR_LIMIT =
Note:

Stability Level: development

The number of OS threads that can execute user-level Go code simultaneously.

Computed from /sched/gomaxprocs:threads.

'go.processor.limit'
GO_SCHEDULE_DURATION =
Note:

Stability Level: development

The time goroutines have spent in the scheduler in a runnable state before actually running.

Computed from /sched/latencies:seconds. Bucket boundaries are provided by the runtime, and are subject to change.

'go.schedule.duration'

Attribute Names collapse

GO_CPU_DETAILED_STATE =
Note:

Stability Level: development

The detailed state of the CPU.

Value SHOULD match the specific CPU class reported by the Go runtime under /cpu/classes/.... The list of possible values is subject to change with the Go version used.

'go.cpu.detailed_state'
GO_CPU_STATE =
Note:

Stability Level: development

The state of the CPU.

'go.cpu.state'
GO_MEMORY_DETAILED_TYPE =
Note:

Stability Level: development

The detailed type of memory.

Value SHOULD match the specific memory class reported by the Go runtime under /memory/classes/.... The list of possible values is subject to change with the Go version used.

'go.memory.detailed_type'
GO_MEMORY_TYPE =
Note:

Stability Level: development

The type of memory.

'go.memory.type'