Module: OpenTelemetry::SemConv::Incubating::HTTP

Defined in:
lib/opentelemetry/semconv/incubating/http/metrics.rb,
lib/opentelemetry/semconv/incubating/http/attributes.rb

Metrics Names collapse

HTTP_CLIENT_ACTIVE_REQUESTS =
Note:

Stability Level: development

Number of active HTTP requests.

'http.client.active_requests'
HTTP_CLIENT_CONNECTION_DURATION =
Note:

Stability Level: development

The duration of the successfully established outbound HTTP connections.

'http.client.connection.duration'
HTTP_CLIENT_OPEN_CONNECTIONS =
Note:

Stability Level: development

Number of outbound HTTP connections that are currently active or idle on the client.

'http.client.open_connections'
HTTP_CLIENT_REQUEST_BODY_SIZE =
Note:

Stability Level: development

Size of HTTP client request bodies.

The size of the request payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.client.request.body.size'
HTTP_CLIENT_REQUEST_DURATION =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_CLIENT_REQUEST_DURATION.

Note:

Stability Level: stable

Duration of HTTP client requests.

'http.client.request.duration'
HTTP_CLIENT_RESPONSE_BODY_SIZE =
Note:

Stability Level: development

Size of HTTP client response bodies.

The size of the response payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.client.response.body.size'
HTTP_SERVER_ACTIVE_REQUESTS =
Note:

Stability Level: development

Number of active HTTP server requests.

'http.server.active_requests'
HTTP_SERVER_REQUEST_BODY_SIZE =
Note:

Stability Level: development

Size of HTTP server request bodies.

The size of the request payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.server.request.body.size'
HTTP_SERVER_REQUEST_DURATION =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_SERVER_REQUEST_DURATION.

Note:

Stability Level: stable

Duration of HTTP server requests.

'http.server.request.duration'
HTTP_SERVER_RESPONSE_BODY_SIZE =
Note:

Stability Level: development

Size of HTTP server response bodies.

The size of the response payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.server.response.body.size'

Attribute Names collapse

HTTP_CLIENT_IP =
Deprecated.

Replaced by client.address.

Note:

Stability Level: development

Deprecated, use client.address instead.

'http.client_ip'
HTTP_CONNECTION_STATE =
Note:

Stability Level: development

State of the HTTP connection in the HTTP connection pool.

'http.connection.state'
HTTP_FLAVOR =
Deprecated.

Split into network.protocol.name and network.protocol.version

Note:

Stability Level: development

Deprecated, use network.protocol.name and network.protocol.version instead.

'http.flavor'
HTTP_HOST =
Deprecated.

Replaced by one of server.address, client.address or http.request.header.host, depending on the usage.

Note:

Stability Level: development

Deprecated, use one of server.address, client.address or http.request.header.host instead, depending on the usage.

'http.host'
HTTP_METHOD =
Deprecated.

Replaced by http.request.method.

Note:

Stability Level: development

Deprecated, use http.request.method instead.

'http.method'
HTTP_REQUEST_BODY_SIZE =
Note:

Stability Level: development

The size of the request payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.request.body.size'
HTTP_REQUEST_HEADER_LAMBDA =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_REQUEST_HEADER_LAMBDA.

Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

HTTP request headers, <key> being the normalized HTTP Header name (lowercase), the value being the header values.

Instrumentations SHOULD require an explicit configuration of which headers are to be captured. Including all request headers can be a security risk - explicit configuration helps avoid leaking sensitive information.

The User-Agent header is already captured in the user_agent.original attribute. Users MAY explicitly configure instrumentations to capture them even though it is not recommended.

The attribute value MUST consist of either multiple header values as an array of strings or a single-item array containing a possibly comma-concatenated string, depending on the way the HTTP library provides access to headers.

Examples:

  • A header Content-Type: application/json SHOULD be recorded as the http.request.header.content-type attribute with value ["application/json"].
  • A header X-Forwarded-For: 1.2.3.4, 1.2.3.5 SHOULD be recorded as the http.request.header.x-forwarded-for attribute with value ["1.2.3.4", "1.2.3.5"] or ["1.2.3.4, 1.2.3.5"] depending on the HTTP library.

Examples:

Usage

HTTP_REQUEST_HEADER_LAMBDA.call('some-cool-key') #=> 'http.request.header.some-cool-key'
->(key) { "http.request.header.#{key}" }
HTTP_REQUEST_METHOD =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_REQUEST_METHOD.

Note:

Stability Level: stable

HTTP request method.

HTTP request method value SHOULD be "known" to the instrumentation. By default, this convention defines "known" methods as the ones listed in RFC9110, the PATCH method defined in RFC5789 and the QUERY method defined in httpbis-safe-method-w-body.

If the HTTP request method is not known to instrumentation, it MUST set the http.request.method attribute to _OTHER.

If the HTTP instrumentation could end up converting valid HTTP request methods to _OTHER, then it MUST provide a way to override the list of known HTTP methods. If this override is done via environment variable, then the environment variable MUST be named OTEL_INSTRUMENTATION_HTTP_KNOWN_METHODS and support a comma-separated list of case-sensitive known HTTP methods (this list MUST be a full override of the default known method, it is not a list of known methods in addition to the defaults).

HTTP method names are case-sensitive and http.request.method attribute value MUST match a known HTTP method name exactly. Instrumentations for specific web frameworks that consider HTTP methods to be case insensitive, SHOULD populate a canonical equivalent. Tracing instrumentations that do so, MUST also set http.request.method_original to the original value.

'http.request.method'
HTTP_REQUEST_METHOD_ORIGINAL =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_REQUEST_METHOD_ORIGINAL.

Note:

Stability Level: stable

Original HTTP method sent by the client in the request line.

'http.request.method_original'
HTTP_REQUEST_RESEND_COUNT =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_REQUEST_RESEND_COUNT.

Note:

Stability Level: stable

The ordinal number of request resending attempt (for any reason, including redirects).

The resend count SHOULD be updated each time an HTTP request gets resent by the client, regardless of what was the cause of the resending (e.g. redirection, authorization failure, 503 Server Unavailable, network issues, or any other).

'http.request.resend_count'
HTTP_REQUEST_SIZE =
Note:

Stability Level: development

The total size of the request in bytes. This should be the total number of bytes sent over the wire, including the request line (HTTP/1.1), framing (HTTP/2 and HTTP/3), headers, and request body if any.

'http.request.size'
HTTP_REQUEST_CONTENT_LENGTH =
Deprecated.

Replaced by http.request.header.content-length.

Note:

Stability Level: development

Deprecated, use http.request.header.content-length instead.

'http.request_content_length'
HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED =
Deprecated.

Replaced by http.request.body.size.

Note:

Stability Level: development

Deprecated, use http.request.body.size instead.

'http.request_content_length_uncompressed'
HTTP_RESPONSE_BODY_SIZE =
Note:

Stability Level: development

The size of the response payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the Content-Length header. For requests using transport encoding, this should be the compressed size.

'http.response.body.size'
HTTP_RESPONSE_HEADER_LAMBDA =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_RESPONSE_HEADER_LAMBDA.

Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

HTTP response headers, <key> being the normalized HTTP Header name (lowercase), the value being the header values.

Instrumentations SHOULD require an explicit configuration of which headers are to be captured. Including all response headers can be a security risk - explicit configuration helps avoid leaking sensitive information.

Users MAY explicitly configure instrumentations to capture them even though it is not recommended.

The attribute value MUST consist of either multiple header values as an array of strings or a single-item array containing a possibly comma-concatenated string, depending on the way the HTTP library provides access to headers.

Examples:

  • A header Content-Type: application/json header SHOULD be recorded as the http.request.response.content-type attribute with value ["application/json"].
  • A header My-custom-header: abc, def header SHOULD be recorded as the http.response.header.my-custom-header attribute with value ["abc", "def"] or ["abc, def"] depending on the HTTP library.

Examples:

Usage

HTTP_RESPONSE_HEADER_LAMBDA.call('some-cool-key') #=> 'http.response.header.some-cool-key'
->(key) { "http.response.header.#{key}" }
HTTP_RESPONSE_SIZE =
Note:

Stability Level: development

The total size of the response in bytes. This should be the total number of bytes sent over the wire, including the status line (HTTP/1.1), framing (HTTP/2 and HTTP/3), headers, and response body and trailers if any.

'http.response.size'
HTTP_RESPONSE_STATUS_CODE =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_RESPONSE_STATUS_CODE.

Note:

Stability Level: stable

HTTP response status code.

'http.response.status_code'
HTTP_RESPONSE_CONTENT_LENGTH =
Deprecated.

Replaced by http.response.header.content-length.

Note:

Stability Level: development

Deprecated, use http.response.header.content-length instead.

'http.response_content_length'
HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED =
Deprecated.

Replaced by http.response.body.size.

Note:

Stability Level: development

Deprecated, use http.response.body.size instead.

'http.response_content_length_uncompressed'
HTTP_ROUTE =
Deprecated.

Now available in the stable namespace at HTTP::HTTP_ROUTE.

Note:

Stability Level: stable

The matched route template for the request. This MUST be low-cardinality and include all static path segments, with dynamic path segments represented with placeholders.

MUST NOT be populated when this is not supported by the HTTP server framework as the route attribute should have low-cardinality and the URI path can NOT substitute it. SHOULD include the application root if there is one.

A static path segment is a part of the route template with a fixed, low-cardinality value. This includes literal strings like /users/ and placeholders that are constrained to a finite, predefined set of values, e.g. {controller} or {action}.

A dynamic path segment is a placeholder for a value that can have high cardinality and is not constrained to a predefined list like static path segments.

Instrumentations SHOULD use routing information provided by the corresponding web framework. They SHOULD pick the most precise source of routing information and MAY support custom route formatting. Instrumentations SHOULD document the format and the API used to obtain the route string.

'http.route'
HTTP_SCHEME =
Deprecated.

Replaced by url.scheme.

Note:

Stability Level: development

Deprecated, use url.scheme instead.

'http.scheme'
HTTP_SERVER_NAME =
Deprecated.

Replaced by server.address.

Note:

Stability Level: development

Deprecated, use server.address instead.

'http.server_name'
HTTP_STATUS_CODE =
Deprecated.

Replaced by http.response.status_code.

Note:

Stability Level: development

Deprecated, use http.response.status_code instead.

'http.status_code'
HTTP_TARGET =
Deprecated.

Split to url.path and url.query.

Note:

Stability Level: development

Deprecated, use url.path and url.query instead.

'http.target'
HTTP_URL =
Deprecated.

Replaced by url.full.

Note:

Stability Level: development

Deprecated, use url.full instead.

'http.url'
HTTP_USER_AGENT =
Deprecated.

Replaced by user_agent.original.

Note:

Stability Level: development

Deprecated, use user_agent.original instead.

'http.user_agent'