Module: OpenTelemetry::SemConv::Incubating::HW

Defined in:
lib/opentelemetry/semconv/incubating/hw/metrics.rb,
lib/opentelemetry/semconv/incubating/hw/attributes.rb

Metrics Names collapse

HW_BATTERY_CHARGE =
Note:

Stability Level: development

Remaining fraction of battery charge.

'hw.battery.charge'
HW_BATTERY_CHARGE_LIMIT =
Note:

Stability Level: development

Lower limit of battery charge fraction to ensure proper operation.

'hw.battery.charge.limit'
HW_BATTERY_TIME_LEFT =
Note:

Stability Level: development

Time left before battery is completely charged or discharged.

'hw.battery.time_left'
HW_CPU_SPEED =
Note:

Stability Level: development

CPU current frequency.

'hw.cpu.speed'
HW_CPU_SPEED_LIMIT =
Note:

Stability Level: development

CPU maximum frequency.

'hw.cpu.speed.limit'
HW_ENERGY =
Note:

Stability Level: development

Energy consumed by the component.

'hw.energy'
HW_ERRORS =
Note:

Stability Level: development

Number of errors encountered by the component.

'hw.errors'
HW_FAN_SPEED =
Note:

Stability Level: development

Fan speed in revolutions per minute.

'hw.fan.speed'
HW_FAN_SPEED_LIMIT =
Note:

Stability Level: development

Speed limit in rpm.

'hw.fan.speed.limit'
HW_FAN_SPEED_RATIO =
Note:

Stability Level: development

Fan speed expressed as a fraction of its maximum speed.

'hw.fan.speed_ratio'
HW_GPU_IO =
Note:

Stability Level: development

Received and transmitted bytes by the GPU.

'hw.gpu.io'
HW_GPU_MEMORY_LIMIT =
Note:

Stability Level: development

Size of the GPU memory.

'hw.gpu.memory.limit'
HW_GPU_MEMORY_USAGE =
Note:

Stability Level: development

GPU memory used.

'hw.gpu.memory.usage'
HW_GPU_MEMORY_UTILIZATION =
Note:

Stability Level: development

Fraction of GPU memory used.

'hw.gpu.memory.utilization'
HW_GPU_UTILIZATION =
Note:

Stability Level: development

Fraction of time spent in a specific task.

'hw.gpu.utilization'
HW_HOST_AMBIENT_TEMPERATURE =
Note:

Stability Level: development

Ambient (external) temperature of the physical host.

'hw.host.ambient_temperature'
HW_HOST_ENERGY =
Note:

Stability Level: development

Total energy consumed by the entire physical host, in joules.

The overall energy usage of a host MUST be reported using the specific hw.host.energy and hw.host.power metrics only, instead of the generic hw.energy and hw.power described in the previous section, to prevent summing up overlapping values.

'hw.host.energy'
HW_HOST_HEATING_MARGIN =
Note:

Stability Level: development

By how many degrees Celsius the temperature of the physical host can be increased, before reaching a warning threshold on one of the internal sensors.

'hw.host.heating_margin'
HW_HOST_POWER =
Note:

Stability Level: development

Instantaneous power consumed by the entire physical host in Watts (hw.host.energy is preferred).

The overall energy usage of a host MUST be reported using the specific hw.host.energy and hw.host.power metrics only, instead of the generic hw.energy and hw.power described in the previous section, to prevent summing up overlapping values.

'hw.host.power'
HW_LOGICAL_DISK_LIMIT =
Note:

Stability Level: development

Size of the logical disk.

'hw.logical_disk.limit'
HW_LOGICAL_DISK_USAGE =
Note:

Stability Level: development

Logical disk space usage.

'hw.logical_disk.usage'
HW_LOGICAL_DISK_UTILIZATION =
Note:

Stability Level: development

Logical disk space utilization as a fraction.

'hw.logical_disk.utilization'
HW_MEMORY_SIZE =
Note:

Stability Level: development

Size of the memory module.

'hw.memory.size'
HW_NETWORK_BANDWIDTH_LIMIT =
Note:

Stability Level: development

Link speed.

'hw.network.bandwidth.limit'
HW_NETWORK_BANDWIDTH_UTILIZATION =
Note:

Stability Level: development

Utilization of the network bandwidth as a fraction.

'hw.network.bandwidth.utilization'
HW_NETWORK_IO =
Note:

Stability Level: development

Received and transmitted network traffic in bytes.

'hw.network.io'
HW_NETWORK_PACKETS =
Note:

Stability Level: development

Received and transmitted network traffic in packets (or frames).

'hw.network.packets'
HW_NETWORK_UP =
Note:

Stability Level: development

Link status: 1 (up) or 0 (down).

'hw.network.up'
HW_PHYSICAL_DISK_ENDURANCE_UTILIZATION =
Note:

Stability Level: development

Endurance remaining for this SSD disk.

'hw.physical_disk.endurance_utilization'
HW_PHYSICAL_DISK_SIZE =
Note:

Stability Level: development

Size of the disk.

'hw.physical_disk.size'
HW_PHYSICAL_DISK_SMART =
Note:

Stability Level: development

Value of the corresponding S.M.A.R.T. (Self-Monitoring, Analysis, and Reporting Technology) attribute.

'hw.physical_disk.smart'
HW_POWER =
Note:

Stability Level: development

Instantaneous power consumed by the component.

It is recommended to report hw.energy instead of hw.power when possible.

'hw.power'
HW_POWER_SUPPLY_LIMIT =
Note:

Stability Level: development

Maximum power output of the power supply.

'hw.power_supply.limit'
HW_POWER_SUPPLY_USAGE =
Note:

Stability Level: development

Current power output of the power supply.

'hw.power_supply.usage'
HW_POWER_SUPPLY_UTILIZATION =
Note:

Stability Level: development

Utilization of the power supply as a fraction of its maximum output.

'hw.power_supply.utilization'
HW_STATUS =
Note:

Stability Level: development

Operational status: 1 (true) or 0 (false) for each of the possible states.

hw.status is currently specified as an UpDownCounter but would ideally be represented using a StateSet as defined in OpenMetrics. This semantic convention will be updated once StateSet is specified in OpenTelemetry. This planned change is not expected to have any consequence on the way users query their timeseries backend to retrieve the values of hw.status over time.

'hw.status'
HW_TAPE_DRIVE_OPERATIONS =
Note:

Stability Level: development

Operations performed by the tape drive.

'hw.tape_drive.operations'
HW_TEMPERATURE =
Note:

Stability Level: development

Temperature in degrees Celsius.

'hw.temperature'
HW_TEMPERATURE_LIMIT =
Note:

Stability Level: development

Temperature limit in degrees Celsius.

'hw.temperature.limit'
HW_VOLTAGE =
Note:

Stability Level: development

Voltage measured by the sensor.

'hw.voltage'
HW_VOLTAGE_LIMIT =
Note:

Stability Level: development

Voltage limit in Volts.

'hw.voltage.limit'
HW_VOLTAGE_NOMINAL =
Note:

Stability Level: development

Nominal (expected) voltage.

'hw.voltage.nominal'

Attribute Names collapse

HW_BATTERY_CAPACITY =
Note:

Stability Level: development

Design capacity in Watts-hours or Amper-hours

'hw.battery.capacity'
HW_BATTERY_CHEMISTRY =
Note:

Stability Level: development

Battery chemistry, e.g. Lithium-Ion, Nickel-Cadmium, etc.

'hw.battery.chemistry'
HW_BATTERY_STATE =
Note:

Stability Level: development

The current state of the battery

'hw.battery.state'
HW_BIOS_VERSION =
Note:

Stability Level: development

BIOS version of the hardware component

'hw.bios_version'
HW_DRIVER_VERSION =
Note:

Stability Level: development

Driver version for the hardware component

'hw.driver_version'
HW_ENCLOSURE_TYPE =
Note:

Stability Level: development

Type of the enclosure (useful for modular systems)

'hw.enclosure.type'
HW_FIRMWARE_VERSION =
Note:

Stability Level: development

Firmware version of the hardware component

'hw.firmware_version'
HW_GPU_TASK =
Note:

Stability Level: development

Type of task the GPU is performing

'hw.gpu.task'
HW_ID =
Note:

Stability Level: development

An identifier for the hardware component, unique within the monitored host

'hw.id'
HW_LIMIT_TYPE =
Note:

Stability Level: development

Type of limit for hardware components

'hw.limit_type'
HW_LOGICAL_DISK_RAID_LEVEL =
Note:

Stability Level: development

RAID Level of the logical disk

'hw.logical_disk.raid_level'
HW_LOGICAL_DISK_STATE =
Note:

Stability Level: development

State of the logical disk space usage

'hw.logical_disk.state'
HW_MEMORY_TYPE =
Note:

Stability Level: development

Type of the memory module

'hw.memory.type'
HW_MODEL =
Note:

Stability Level: development

Descriptive model name of the hardware component

'hw.model'
HW_NAME =
Note:

Stability Level: development

An easily-recognizable name for the hardware component

'hw.name'
HW_NETWORK_LOGICAL_ADDRESSES =
Note:

Stability Level: development

Logical addresses of the adapter (e.g. IP address, or WWPN)

'hw.network.logical_addresses'
HW_NETWORK_PHYSICAL_ADDRESS =
Note:

Stability Level: development

Physical address of the adapter (e.g. MAC address, or WWNN)

'hw.network.physical_address'
HW_PARENT =
Note:

Stability Level: development

Unique identifier of the parent component (typically the hw.id attribute of the enclosure, or disk controller)

'hw.parent'
HW_PHYSICAL_DISK_SMART_ATTRIBUTE =
Note:

Stability Level: development

S.M.A.R.T. (Self-Monitoring, Analysis, and Reporting Technology) attribute of the physical disk

'hw.physical_disk.smart_attribute'
HW_PHYSICAL_DISK_STATE =
Note:

Stability Level: development

State of the physical disk endurance utilization

'hw.physical_disk.state'
HW_PHYSICAL_DISK_TYPE =
Note:

Stability Level: development

Type of the physical disk

'hw.physical_disk.type'
HW_SENSOR_LOCATION =
Note:

Stability Level: development

Location of the sensor

'hw.sensor_location'
HW_SERIAL_NUMBER =
Note:

Stability Level: development

Serial number of the hardware component

'hw.serial_number'
HW_STATE =
Note:

Stability Level: development

The current state of the component

'hw.state'
HW_TAPE_DRIVE_OPERATION_TYPE =
Note:

Stability Level: development

Type of tape drive operation

'hw.tape_drive.operation_type'
HW_TYPE =
Note:

Stability Level: development

Type of the component

Describes the category of the hardware component for which hw.state is being reported. For example, hw.type=temperature along with hw.state=degraded would indicate that the temperature of the hardware component has been reported as degraded.

'hw.type'
HW_VENDOR =
Note:

Stability Level: development

Vendor name of the hardware component

'hw.vendor'