Module: OpenTelemetry::SemConv::Incubating::MCP

Defined in:
lib/opentelemetry/semconv/incubating/mcp/metrics.rb,
lib/opentelemetry/semconv/incubating/mcp/attributes.rb

Metrics Names collapse

MCP_CLIENT_OPERATION_DURATION =
Note:

Stability Level: development

The duration of the MCP request or notification as observed on the sender from the time it was sent until the response or ack is received.

'mcp.client.operation.duration'
MCP_CLIENT_SESSION_DURATION =
Note:

Stability Level: development

The duration of the MCP session as observed on the MCP client.

'mcp.client.session.duration'
MCP_SERVER_OPERATION_DURATION =
Note:

Stability Level: development

MCP request or notification duration as observed on the receiver from the time it was received until the result or ack is sent.

'mcp.server.operation.duration'
MCP_SERVER_SESSION_DURATION =
Note:

Stability Level: development

The duration of the MCP session as observed on the MCP server.

'mcp.server.session.duration'

Attribute Names collapse

MCP_METHOD_NAME =
Note:

Stability Level: development

The name of the request or notification method.

'mcp.method.name'
MCP_PROTOCOL_VERSION =
Note:

Stability Level: development

The version of the Model Context Protocol used.

'mcp.protocol.version'
MCP_RESOURCE_URI =
Note:

Stability Level: development

The value of the resource uri.

This is a URI of the resource provided in the following requests or notifications: resources/read, resources/subscribe, resources/unsubscribe, or notifications/resources/updated.

'mcp.resource.uri'
MCP_SESSION_ID =
Note:

Stability Level: development

Identifies MCP session.

'mcp.session.id'