Module: OpenTelemetry::SemConv::Incubating::NFS

Defined in:
lib/opentelemetry/semconv/incubating/nfs/metrics.rb,
lib/opentelemetry/semconv/incubating/nfs/attributes.rb

Metrics Names collapse

NFS_CLIENT_NET_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS client TCP segments and UDP datagrams handled.

Linux: this metric is taken from the Linux kernel's svc_stat.netudpcnt and svc_stat.nettcpcnt

'nfs.client.net.count'
NFS_CLIENT_NET_TCP_CONNECTION_ACCEPTED =
Note:

Stability Level: development

Reports the count of kernel NFS client TCP connections accepted.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

'nfs.client.net.tcp.connection.accepted'
NFS_CLIENT_OPERATION_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFSv4+ client operations.

'nfs.client.operation.count'
NFS_CLIENT_PROCEDURE_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS client procedures.

'nfs.client.procedure.count'
NFS_CLIENT_RPC_AUTHREFRESH_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS client RPC authentication refreshes.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcauthrefresh

'nfs.client.rpc.authrefresh.count'
NFS_CLIENT_RPC_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS client RPCs sent, regardless of whether they're accepted/rejected by the server.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt

'nfs.client.rpc.count'
NFS_CLIENT_RPC_RETRANSMIT_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS client RPC retransmits.

Linux: this metric is taken from the Linux kernel's svc_stat.rpcretrans

'nfs.client.rpc.retransmit.count'
NFS_SERVER_FH_STALE_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS server stale file handles.

Linux: this metric is taken from the Linux kernel NFSD_STATS_FH_STALE counter in the nfsd_net struct

'nfs.server.fh.stale.count'
NFS_SERVER_IO =
Note:

Stability Level: development

Reports the count of kernel NFS server bytes returned to receive and transmit (read and write) requests.

Linux: this metric is taken from the Linux kernel NFSD_STATS_IO_READ and NFSD_STATS_IO_WRITE counters in the nfsd_net struct

'nfs.server.io'
NFS_SERVER_NET_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS server TCP segments and UDP datagrams handled.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpcnt and svc_stat.netudpcnt

'nfs.server.net.count'
NFS_SERVER_NET_TCP_CONNECTION_ACCEPTED =
Note:

Stability Level: development

Reports the count of kernel NFS server TCP connections accepted.

Linux: this metric is taken from the Linux kernel's svc_stat.nettcpconn

'nfs.server.net.tcp.connection.accepted'
NFS_SERVER_OPERATION_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFSv4+ server operations.

'nfs.server.operation.count'
NFS_SERVER_PROCEDURE_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS server procedures.

'nfs.server.procedure.count'
NFS_SERVER_REPCACHE_REQUESTS =
Note:

Stability Level: development

Reports the kernel NFS server reply cache request count by cache hit status.

'nfs.server.repcache.requests'
NFS_SERVER_RPC_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS server RPCs handled.

Linux: this metric is taken from the Linux kernel's svc_stat.rpccnt, the count of good RPCs. This metric can have an error.type of "format", "auth", or "client" for svc_stat.badfmt, svc_stat.badauth, and svc_stat.badclnt.

'nfs.server.rpc.count'
NFS_SERVER_THREAD_COUNT =
Note:

Stability Level: development

Reports the count of kernel NFS server available threads.

Linux: this metric is taken from the Linux kernel nfsd_th_cnt variable

'nfs.server.thread.count'

Attribute Names collapse

NFS_OPERATION_NAME =
Note:

Stability Level: development

NFSv4+ operation name.

'nfs.operation.name'
NFS_SERVER_REPCACHE_STATUS =
Note:

Stability Level: development

Linux: one of "hit" (NFSD_STATS_RC_HITS), "miss" (NFSD_STATS_RC_MISSES), or "nocache" (NFSD_STATS_RC_NOCACHE -- uncacheable)

'nfs.server.repcache.status'