Module: OpenTelemetry::SemConv::Incubating::OS

Defined in:
lib/opentelemetry/semconv/incubating/os/attributes.rb

Attribute Names collapse

OS_BUILD_ID =
Note:

Stability Level: development

Unique identifier for a particular build or compilation of the operating system.

'os.build_id'
OS_DESCRIPTION =
Note:

Stability Level: development

Human readable (not intended to be parsed) OS version information, like e.g. reported by ver or lsb_release -a commands.

'os.description'
OS_NAME =
Note:

Stability Level: development

Human readable operating system name.

'os.name'
OS_TYPE =
Note:

Stability Level: development

The operating system type.

'os.type'
OS_VERSION =
Note:

Stability Level: development

The version string of the operating system as defined in Version Attributes.

'os.version'