Module: OpenTelemetry::SemConv::Incubating::SECURITY_RULE

Defined in:
lib/opentelemetry/semconv/incubating/security_rule/attributes.rb

Attribute Names collapse

SECURITY_RULE_CATEGORY =
Note:

Stability Level: development

A categorization value keyword used by the entity using the rule for detection of this event

'security_rule.category'
SECURITY_RULE_DESCRIPTION =
Note:

Stability Level: development

The description of the rule generating the event.

'security_rule.description'
SECURITY_RULE_LICENSE =
Note:

Stability Level: development

Name of the license under which the rule used to generate this event is made available.

'security_rule.license'
SECURITY_RULE_NAME =
Note:

Stability Level: development

The name of the rule or signature generating the event.

'security_rule.name'
SECURITY_RULE_REFERENCE =
Note:

Stability Level: development

Reference URL to additional information about the rule used to generate this event.

The URL can point to the vendor’s documentation about the rule. If that’s not available, it can also be a link to a more general page describing this type of alert.

'security_rule.reference'
SECURITY_RULE_RULESET_NAME =
Note:

Stability Level: development

Name of the ruleset, policy, group, or parent category in which the rule used to generate this event is a member.

'security_rule.ruleset.name'
SECURITY_RULE_UUID =
Note:

Stability Level: development

A rule ID that is unique within the scope of a set or group of agents, observers, or other entities using the rule for detection of this event.

'security_rule.uuid'
SECURITY_RULE_VERSION =
Note:

Stability Level: development

The version / revision of the rule being used for analysis.

'security_rule.version'