Module: OpenTelemetry::SemConv::Incubating::SYSTEM

Defined in:
lib/opentelemetry/semconv/incubating/system/metrics.rb,
lib/opentelemetry/semconv/incubating/system/attributes.rb

Metrics Names collapse

SYSTEM_CPU_FREQUENCY =
Note:

Stability Level: development

Operating frequency of the logical CPU in Hertz.

'system.cpu.frequency'
SYSTEM_CPU_LOGICAL_COUNT =
Note:

Stability Level: development

Reports the number of logical (virtual) processor cores created by the operating system to manage multitasking.

Calculated by multiplying the number of sockets by the number of cores per socket, and then by the number of threads per core

'system.cpu.logical.count'
SYSTEM_CPU_PHYSICAL_COUNT =
Note:

Stability Level: development

Reports the number of actual physical processor cores on the hardware.

Calculated by multiplying the number of sockets by the number of cores per socket

'system.cpu.physical.count'
SYSTEM_CPU_TIME =
Note:

Stability Level: development

Seconds each logical CPU spent on each mode.

'system.cpu.time'
SYSTEM_CPU_UTILIZATION =
Note:

Stability Level: development

For each logical CPU, the utilization is calculated as the change in cumulative CPU time (cpu.time) over a measurement interval, divided by the elapsed time.

'system.cpu.utilization'
SYSTEM_DISK_IO =
Note:

Stability Level: development

Disk bytes transferred.

'system.disk.io'
SYSTEM_DISK_IO_TIME =
Note:

Stability Level: development

Time disk spent activated.

The real elapsed time ("wall clock") used in the I/O path (time from operations running in parallel are not counted). Measured as:

'system.disk.io_time'
SYSTEM_DISK_LIMIT =
Note:

Stability Level: development

The total storage capacity of the disk.

'system.disk.limit'
SYSTEM_DISK_MERGED =
Note:

Stability Level: development

The number of disk reads/writes merged into single physical disk access operations.

'system.disk.merged'
SYSTEM_DISK_OPERATION_TIME =
Note:

Stability Level: development

Sum of the time each operation took to complete.

Because it is the sum of time each request took, parallel-issued requests each contribute to make the count grow. Measured as:

  • Linux: Fields 7 & 11 from procfs-diskstats
  • Windows: "Avg. Disk sec/Read" perf counter multiplied by "Disk Reads/sec" perf counter (similar for Writes)
'system.disk.operation_time'
SYSTEM_DISK_OPERATIONS =
Note:

Stability Level: development

Disk operations count.

'system.disk.operations'
SYSTEM_FILESYSTEM_LIMIT =
Note:

Stability Level: development

The total storage capacity of the filesystem.

'system.filesystem.limit'
SYSTEM_FILESYSTEM_USAGE =
Note:

Stability Level: development

Reports a filesystem's space usage across different states.

The sum of all system.filesystem.usage values over the different system.filesystem.state attributes SHOULD equal the total storage capacity of the filesystem, that is system.filesystem.limit.

'system.filesystem.usage'
SYSTEM_FILESYSTEM_UTILIZATION =
Note:

Stability Level: development

Fraction of filesystem bytes used.

'system.filesystem.utilization'
SYSTEM_LINUX_MEMORY_AVAILABLE =
Note:

Stability Level: development

An estimate of how much memory is available for starting new applications, without causing swapping.

This is an alternative to system.memory.usage metric with state=free. Linux starting from 3.14 exports "available" memory. It takes "free" memory as a baseline, and then factors in kernel-specific values. This is supposed to be more accurate than just "free" memory. For reference, see the calculations here. See also MemAvailable in /proc/meminfo.

'system.linux.memory.available'
SYSTEM_LINUX_MEMORY_SLAB_USAGE =
Note:

Stability Level: development

Reports the memory used by the Linux kernel for managing caches of frequently used objects.

The sum over the reclaimable and unreclaimable state values in linux.memory.slab.usage SHOULD be equal to the total slab memory available on the system. Note that the total slab memory is not constant and may vary over time. See also the Slab allocator and Slab in /proc/meminfo.

'system.linux.memory.slab.usage'
SYSTEM_MEMORY_LIMIT =
Note:

Stability Level: development

Total virtual memory available in the system.

'system.memory.limit'
SYSTEM_MEMORY_SHARED =
Note:

Stability Level: development

Shared memory used (mostly by tmpfs).

Equivalent of shared from free command or Shmem from /proc/meminfo"

'system.memory.shared'
SYSTEM_MEMORY_USAGE =
Note:

Stability Level: development

Reports memory in use by state.

'system.memory.usage'
SYSTEM_MEMORY_UTILIZATION =
Note:

Stability Level: development

Percentage of memory bytes in use.

'system.memory.utilization'
SYSTEM_NETWORK_CONNECTION_COUNT =
Note:

Stability Level: development

The number of connections.

'system.network.connection.count'
SYSTEM_NETWORK_CONNECTIONS =
Deprecated.

Replaced by system.network.connection.count.

Note:

Stability Level: development

Deprecated, use system.network.connection.count instead.

'system.network.connections'
SYSTEM_NETWORK_DROPPED =
Deprecated.

Replaced by system.network.packet.dropped.

Note:

Stability Level: development

Count of packets that are dropped or discarded even though there was no error.

Measured as:

'system.network.dropped'
SYSTEM_NETWORK_ERRORS =
Note:

Stability Level: development

Count of network errors detected.

Measured as:

'system.network.errors'
SYSTEM_NETWORK_IO =
Note:

Stability Level: development

The number of bytes transmitted and received.

'system.network.io'
SYSTEM_NETWORK_PACKET_COUNT =
Note:

Stability Level: development

The number of packets transferred.

'system.network.packet.count'
SYSTEM_NETWORK_PACKET_DROPPED =
Note:

Stability Level: development

Count of packets that are dropped or discarded even though there was no error.

Measured as:

'system.network.packet.dropped'
SYSTEM_NETWORK_PACKETS =
Deprecated.

Replaced by system.network.packet.count.

Note:

Stability Level: development

The number of packets transferred.

'system.network.packets'
SYSTEM_PAGING_FAULTS =
Note:

Stability Level: development

The number of page faults.

'system.paging.faults'
SYSTEM_PAGING_OPERATIONS =
Note:

Stability Level: development

The number of paging operations.

'system.paging.operations'
SYSTEM_PAGING_USAGE =
Note:

Stability Level: development

Unix swap or windows pagefile usage.

'system.paging.usage'
SYSTEM_PAGING_UTILIZATION =
Note:

Stability Level: development

Swap (unix) or pagefile (windows) utilization.

'system.paging.utilization'
SYSTEM_PROCESS_COUNT =
Note:

Stability Level: development

Total number of processes in each state.

'system.process.count'
SYSTEM_PROCESS_CREATED =
Note:

Stability Level: development

Total number of processes created over uptime of the host.

'system.process.created'
SYSTEM_UPTIME =
Note:

Stability Level: development

The time the system has been running.

Instrumentations SHOULD use a gauge with type double and measure uptime in seconds as a floating point number with the highest precision available. The actual accuracy would depend on the instrumentation and operating system.

'system.uptime'

Attribute Names collapse

SYSTEM_CPU_LOGICAL_NUMBER =
Deprecated.

Replaced by cpu.logical_number.

Note:

Stability Level: development

Deprecated, use cpu.logical_number instead.

'system.cpu.logical_number'
SYSTEM_CPU_STATE =
Deprecated.

Replaced by cpu.mode.

Note:

Stability Level: development

Deprecated, use cpu.mode instead.

'system.cpu.state'
SYSTEM_DEVICE =
Note:

Stability Level: development

The device identifier

'system.device'
SYSTEM_FILESYSTEM_MODE =
Note:

Stability Level: development

The filesystem mode

'system.filesystem.mode'
SYSTEM_FILESYSTEM_MOUNTPOINT =
Note:

Stability Level: development

The filesystem mount path

'system.filesystem.mountpoint'
SYSTEM_FILESYSTEM_STATE =
Note:

Stability Level: development

The filesystem state

'system.filesystem.state'
SYSTEM_FILESYSTEM_TYPE =
Note:

Stability Level: development

The filesystem type

'system.filesystem.type'
SYSTEM_MEMORY_STATE =
Note:

Stability Level: development

The memory state

'system.memory.state'
SYSTEM_NETWORK_STATE =
Deprecated.

Replaced by network.connection.state.

Note:

Stability Level: development

Deprecated, use network.connection.state instead.

'system.network.state'
SYSTEM_PAGING_DIRECTION =
Note:

Stability Level: development

The paging access direction

'system.paging.direction'
SYSTEM_PAGING_FAULT_TYPE =
Note:

Stability Level: development

The paging fault type

'system.paging.fault.type'
SYSTEM_PAGING_STATE =
Note:

Stability Level: development

The memory paging state

'system.paging.state'
SYSTEM_PAGING_TYPE =
Deprecated.

Replaced by system.paging.fault.type.

Note:

Stability Level: development

Deprecated, use system.paging.fault.type instead.

'system.paging.type'
SYSTEM_PROCESS_STATUS =
Deprecated.

Replaced by process.state.

Note:

Stability Level: development

Deprecated, use process.state instead.

'system.process.status'
SYSTEM_PROCESSES_STATUS =
Deprecated.

Replaced by process.state.

Note:

Stability Level: development

Deprecated, use process.state instead.

'system.processes.status'