Module: OpenTelemetry::SemConv::Incubating::TEST

Defined in:
lib/opentelemetry/semconv/incubating/test/attributes.rb

Attribute Names collapse

TEST_CASE_NAME =
Note:

Stability Level: development

The fully qualified human readable name of the test case.

'test.case.name'
TEST_CASE_RESULT_STATUS =
Note:

Stability Level: development

The status of the actual test case result from test execution.

'test.case.result.status'
TEST_SUITE_NAME =
Note:

Stability Level: development

The human readable name of a test suite.

'test.suite.name'
TEST_SUITE_RUN_STATUS =
Note:

Stability Level: development

The status of the test suite run.

'test.suite.run.status'