Module: OpenTelemetry::SemConv::Incubating::THREAD

Defined in:
lib/opentelemetry/semconv/incubating/thread/attributes.rb

Attribute Names collapse

THREAD_ID =
Note:

Stability Level: development

Current "managed" thread ID (as opposed to OS thread ID).

Examples of where the value can be extracted from:

Language or platform Source
JVM Thread.currentThread().threadId()
.NET Thread.CurrentThread.ManagedThreadId
Python threading.current_thread().ident
Ruby Thread.current.object_id
C++ std::this_thread::get_id()
Erlang erlang:self()
'thread.id'
THREAD_NAME =
Note:

Stability Level: development

Current thread name.

Examples of where the value can be extracted from:

Language or platform Source
JVM Thread.currentThread().getName()
.NET Thread.CurrentThread.Name
Python threading.current_thread().name
Ruby Thread.current.name
Erlang erlang:process_info(self(), registered_name)
'thread.name'