Module: OpenTelemetry::SemConv::Incubating::USER

Defined in:
lib/opentelemetry/semconv/incubating/user/attributes.rb

Attribute Names collapse

USER_EMAIL =
Note:

Stability Level: development

User email address.

'user.email'
USER_FULL_NAME =
Note:

Stability Level: development

User's full name

'user.full_name'
USER_HASH =
Note:

Stability Level: development

Unique user hash to correlate information for a user in anonymized form.

Useful if user.id or user.name contain confidential information and cannot be used.

'user.hash'
USER_ID =
Note:

Stability Level: development

Unique identifier of the user.

'user.id'
USER_NAME =
Note:

Stability Level: development

Short name or login/username of the user.

'user.name'
USER_ROLES =
Note:

Stability Level: development

Array of user roles at the time of the event.

'user.roles'