Module: OpenTelemetry::SemConv::K8S

Defined in:
lib/opentelemetry/semconv/k8s/attributes.rb

Attribute Names collapse

K8S_CLUSTER_NAME =
Note:

Stability Level: stable

The name of the cluster.

'k8s.cluster.name'
K8S_CLUSTER_UID =
Note:

Stability Level: stable

A pseudo-ID for the cluster, set to the UID of the kube-system namespace.

K8s doesn't have support for obtaining a cluster ID. If this is ever added, we will recommend collecting the k8s.cluster.uid through the official APIs. In the meantime, we are able to use the uid of the kube-system namespace as a proxy for cluster ID. Read on for the rationale.

Every object created in a K8s cluster is assigned a distinct UID. The kube-system namespace is used by Kubernetes itself and will exist for the lifetime of the cluster. Using the uid of the kube-system namespace is a reasonable proxy for the K8s ClusterID as it will only change if the cluster is rebuilt. Furthermore, Kubernetes UIDs are UUIDs as standardized by ISO/IEC 9834-8 and ITU-T X.667. Which states:

If generated according to one of the mechanisms defined in Rec. ITU-T X.667 | ISO/IEC 9834-8, a UUID is either guaranteed to be different from all other UUIDs generated before 3603 A.D., or is extremely likely to be different (depending on the mechanism chosen).

Therefore, UIDs between clusters should be extremely unlikely to conflict.

'k8s.cluster.uid'
K8S_CONTAINER_NAME =
Note:

Stability Level: stable

The name of the Container from Pod specification, must be unique within a Pod. Container runtime usually uses different globally unique name (container.name).

'k8s.container.name'
K8S_CONTAINER_RESTART_COUNT =
Note:

Stability Level: stable

Number of times the container was restarted. This attribute can be used to identify a particular container (running or stopped) within a container spec.

'k8s.container.restart_count'
K8S_CRONJOB_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The cronjob annotation placed on the CronJob, the <key> being the annotation name, the value being the annotation value.

Examples:

  • An annotation retries with value 4 SHOULD be recorded as the k8s.cronjob.annotation.retries attribute with value "4".
  • An annotation data with empty string value SHOULD be recorded as the k8s.cronjob.annotation.data attribute with value "".

Examples:

Usage

K8S_CRONJOB_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.cronjob.annotation.some-cool-key'
->(key) { "k8s.cronjob.annotation.#{key}" }
K8S_CRONJOB_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the CronJob, the <key> being the label name, the value being the label value.

Examples:

  • A label type with value weekly SHOULD be recorded as the k8s.cronjob.label.type attribute with value "weekly".
  • A label automated with empty string value SHOULD be recorded as the k8s.cronjob.label.automated attribute with value "".

Examples:

Usage

K8S_CRONJOB_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.cronjob.label.some-cool-key'
->(key) { "k8s.cronjob.label.#{key}" }
K8S_CRONJOB_NAME =
Note:

Stability Level: stable

The name of the CronJob.

'k8s.cronjob.name'
K8S_CRONJOB_UID =
Note:

Stability Level: stable

The UID of the CronJob.

'k8s.cronjob.uid'
K8S_DAEMONSET_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the DaemonSet, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label replicas with value 1 SHOULD be recorded as the k8s.daemonset.annotation.replicas attribute with value "1".
  • A label data with empty string value SHOULD be recorded as the k8s.daemonset.annotation.data attribute with value "".

Examples:

Usage

K8S_DAEMONSET_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.daemonset.annotation.some-cool-key'
->(key) { "k8s.daemonset.annotation.#{key}" }
K8S_DAEMONSET_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the DaemonSet, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label app with value guestbook SHOULD be recorded as the k8s.daemonset.label.app attribute with value "guestbook".
  • A label data with empty string value SHOULD be recorded as the k8s.daemonset.label.injected attribute with value "".

Examples:

Usage

K8S_DAEMONSET_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.daemonset.label.some-cool-key'
->(key) { "k8s.daemonset.label.#{key}" }
K8S_DAEMONSET_NAME =
Note:

Stability Level: stable

The name of the DaemonSet.

'k8s.daemonset.name'
K8S_DAEMONSET_UID =
Note:

Stability Level: stable

The UID of the DaemonSet.

'k8s.daemonset.uid'
K8S_DEPLOYMENT_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the Deployment, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label replicas with value 1 SHOULD be recorded as the k8s.deployment.annotation.replicas attribute with value "1".
  • A label data with empty string value SHOULD be recorded as the k8s.deployment.annotation.data attribute with value "".

Examples:

Usage

K8S_DEPLOYMENT_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.deployment.annotation.some-cool-key'
->(key) { "k8s.deployment.annotation.#{key}" }
K8S_DEPLOYMENT_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the Deployment, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label replicas with value 0 SHOULD be recorded as the k8s.deployment.label.app attribute with value "guestbook".
  • A label injected with empty string value SHOULD be recorded as the k8s.deployment.label.injected attribute with value "".

Examples:

Usage

K8S_DEPLOYMENT_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.deployment.label.some-cool-key'
->(key) { "k8s.deployment.label.#{key}" }
K8S_DEPLOYMENT_NAME =
Note:

Stability Level: stable

The name of the Deployment.

'k8s.deployment.name'
K8S_DEPLOYMENT_UID =
Note:

Stability Level: stable

The UID of the Deployment.

'k8s.deployment.uid'
K8S_JOB_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the Job, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label number with value 1 SHOULD be recorded as the k8s.job.annotation.number attribute with value "1".
  • A label data with empty string value SHOULD be recorded as the k8s.job.annotation.data attribute with value "".

Examples:

Usage

K8S_JOB_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.job.annotation.some-cool-key'
->(key) { "k8s.job.annotation.#{key}" }
K8S_JOB_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the Job, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label jobtype with value ci SHOULD be recorded as the k8s.job.label.jobtype attribute with value "ci".
  • A label data with empty string value SHOULD be recorded as the k8s.job.label.automated attribute with value "".

Examples:

Usage

K8S_JOB_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.job.label.some-cool-key'
->(key) { "k8s.job.label.#{key}" }
K8S_JOB_NAME =
Note:

Stability Level: stable

The name of the Job.

'k8s.job.name'
K8S_JOB_UID =
Note:

Stability Level: stable

The UID of the Job.

'k8s.job.uid'
K8S_NAMESPACE_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the Namespace, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label ttl with value 0 SHOULD be recorded as the k8s.namespace.annotation.ttl attribute with value "0".
  • A label data with empty string value SHOULD be recorded as the k8s.namespace.annotation.data attribute with value "".

Examples:

Usage

K8S_NAMESPACE_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.namespace.annotation.some-cool-key'
->(key) { "k8s.namespace.annotation.#{key}" }
K8S_NAMESPACE_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the Namespace, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label kubernetes.io/metadata.name with value default SHOULD be recorded as the k8s.namespace.label.kubernetes.io/metadata.name attribute with value "default".
  • A label data with empty string value SHOULD be recorded as the k8s.namespace.label.data attribute with value "".

Examples:

Usage

K8S_NAMESPACE_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.namespace.label.some-cool-key'
->(key) { "k8s.namespace.label.#{key}" }
K8S_NAMESPACE_NAME =
Note:

Stability Level: stable

The name of the namespace that the pod is running in.

'k8s.namespace.name'
K8S_NODE_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the Node, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • An annotation node.alpha.kubernetes.io/ttl with value 0 SHOULD be recorded as the k8s.node.annotation.node.alpha.kubernetes.io/ttl attribute with value "0".
  • An annotation data with empty string value SHOULD be recorded as the k8s.node.annotation.data attribute with value "".

Examples:

Usage

K8S_NODE_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.node.annotation.some-cool-key'
->(key) { "k8s.node.annotation.#{key}" }
K8S_NODE_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the Node, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label kubernetes.io/arch with value arm64 SHOULD be recorded as the k8s.node.label.kubernetes.io/arch attribute with value "arm64".
  • A label data with empty string value SHOULD be recorded as the k8s.node.label.data attribute with value "".

Examples:

Usage

K8S_NODE_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.node.label.some-cool-key'
->(key) { "k8s.node.label.#{key}" }
K8S_NODE_NAME =
Note:

Stability Level: stable

The name of the Node.

'k8s.node.name'
K8S_NODE_UID =
Note:

Stability Level: stable

The UID of the Node.

'k8s.node.uid'
K8S_POD_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the Pod, the <key> being the annotation name, the value being the annotation value.

Examples:

  • An annotation kubernetes.io/enforce-mountable-secrets with value true SHOULD be recorded as the k8s.pod.annotation.kubernetes.io/enforce-mountable-secrets attribute with value "true".
  • An annotation mycompany.io/arch with value x64 SHOULD be recorded as the k8s.pod.annotation.mycompany.io/arch attribute with value "x64".
  • An annotation data with empty string value SHOULD be recorded as the k8s.pod.annotation.data attribute with value "".

Examples:

Usage

K8S_POD_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.pod.annotation.some-cool-key'
->(key) { "k8s.pod.annotation.#{key}" }
K8S_POD_HOSTNAME =
Note:

Stability Level: stable

Specifies the hostname of the Pod.

The K8s Pod spec has an optional hostname field, which can be used to specify a hostname. Refer to K8s docs for more information about this field.

This attribute aligns with the hostname field of the K8s PodSpec.

'k8s.pod.hostname'
K8S_POD_IP =
Note:

Stability Level: stable

IP address allocated to the Pod.

This attribute aligns with the podIP field of the K8s PodStatus.

'k8s.pod.ip'
K8S_POD_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the Pod, the <key> being the label name, the value being the label value.

Examples:

  • A label app with value my-app SHOULD be recorded as the k8s.pod.label.app attribute with value "my-app".
  • A label mycompany.io/arch with value x64 SHOULD be recorded as the k8s.pod.label.mycompany.io/arch attribute with value "x64".
  • A label data with empty string value SHOULD be recorded as the k8s.pod.label.data attribute with value "".

Examples:

Usage

K8S_POD_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.pod.label.some-cool-key'
->(key) { "k8s.pod.label.#{key}" }
K8S_POD_NAME =
Note:

Stability Level: stable

The name of the Pod.

'k8s.pod.name'
K8S_POD_START_TIME =
Note:

Stability Level: stable

The start timestamp of the Pod.

Date and time at which the object was acknowledged by the Kubelet. This is before the Kubelet pulled the container image(s) for the pod.

This attribute aligns with the startTime field of the K8s PodStatus, in ISO 8601 (RFC 3339 compatible) format.

'k8s.pod.start_time'
K8S_POD_UID =
Note:

Stability Level: stable

The UID of the Pod.

'k8s.pod.uid'
K8S_REPLICASET_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the ReplicaSet, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label replicas with value 0 SHOULD be recorded as the k8s.replicaset.annotation.replicas attribute with value "0".
  • A label data with empty string value SHOULD be recorded as the k8s.replicaset.annotation.data attribute with value "".

Examples:

Usage

K8S_REPLICASET_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.replicaset.annotation.some-cool-key'
->(key) { "k8s.replicaset.annotation.#{key}" }
K8S_REPLICASET_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the ReplicaSet, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label app with value guestbook SHOULD be recorded as the k8s.replicaset.label.app attribute with value "guestbook".
  • A label injected with empty string value SHOULD be recorded as the k8s.replicaset.label.injected attribute with value "".

Examples:

Usage

K8S_REPLICASET_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.replicaset.label.some-cool-key'
->(key) { "k8s.replicaset.label.#{key}" }
K8S_REPLICASET_NAME =
Note:

Stability Level: stable

The name of the ReplicaSet.

'k8s.replicaset.name'
K8S_REPLICASET_UID =
Note:

Stability Level: stable

The UID of the ReplicaSet.

'k8s.replicaset.uid'
K8S_STATEFULSET_ANNOTATION_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The annotation placed on the StatefulSet, the <key> being the annotation name, the value being the annotation value, even if the value is empty.

Examples:

  • A label replicas with value 1 SHOULD be recorded as the k8s.statefulset.annotation.replicas attribute with value "1".
  • A label data with empty string value SHOULD be recorded as the k8s.statefulset.annotation.data attribute with value "".

Examples:

Usage

K8S_STATEFULSET_ANNOTATION_LAMBDA.call('some-cool-key') #=> 'k8s.statefulset.annotation.some-cool-key'
->(key) { "k8s.statefulset.annotation.#{key}" }
K8S_STATEFULSET_LABEL_LAMBDA =
Note:

Stability Level: stable

Must be called with a key for the full attribute name. See notes below about the expectations for the state of the key.

The label placed on the StatefulSet, the <key> being the label name, the value being the label value, even if the value is empty.

Examples:

  • A label replicas with value 0 SHOULD be recorded as the k8s.statefulset.label.app attribute with value "guestbook".
  • A label injected with empty string value SHOULD be recorded as the k8s.statefulset.label.injected attribute with value "".

Examples:

Usage

K8S_STATEFULSET_LABEL_LAMBDA.call('some-cool-key') #=> 'k8s.statefulset.label.some-cool-key'
->(key) { "k8s.statefulset.label.#{key}" }
K8S_STATEFULSET_NAME =
Note:

Stability Level: stable

The name of the StatefulSet.

'k8s.statefulset.name'
K8S_STATEFULSET_UID =
Note:

Stability Level: stable

The UID of the StatefulSet.

'k8s.statefulset.uid'