Module: OpenTelemetry::SemConv::NETWORK

Defined in:
lib/opentelemetry/semconv/network/attributes.rb

Attribute Names collapse

NETWORK_LOCAL_ADDRESS =
Note:

Stability Level: stable

Local address of the network connection - IP address or Unix domain socket name.

'network.local.address'
NETWORK_LOCAL_PORT =
Note:

Stability Level: stable

Local port number of the network connection.

'network.local.port'
NETWORK_PEER_ADDRESS =
Note:

Stability Level: stable

Peer address of the network connection - IP address or Unix domain socket name.

'network.peer.address'
NETWORK_PEER_PORT =
Note:

Stability Level: stable

Peer port number of the network connection.

'network.peer.port'
NETWORK_PROTOCOL_NAME =
Note:

Stability Level: stable

OSI application layer or non-OSI equivalent.

The value SHOULD be normalized to lowercase.

'network.protocol.name'
NETWORK_PROTOCOL_VERSION =
Note:

Stability Level: stable

The actual version of the protocol used for network communication.

If protocol version is subject to negotiation (for example using ALPN), this attribute SHOULD be set to the negotiated version. If the actual protocol version is not known, this attribute SHOULD NOT be set.

'network.protocol.version'
NETWORK_TRANSPORT =
Note:

Stability Level: stable

OSI transport layer or inter-process communication method.

The value SHOULD be normalized to lowercase.

Consider always setting the transport when setting a port number, since a port number is ambiguous without knowing the transport. For example different processes could be listening on TCP port 12345 and UDP port 12345.

'network.transport'
NETWORK_TYPE =
Note:

Stability Level: stable

OSI network layer or non-OSI equivalent.

The value SHOULD be normalized to lowercase.

'network.type'