Module: OpenTelemetry::SemanticConventions
- Defined in:
- lib/opentelemetry/semantic_conventions.rb,
lib/opentelemetry/semantic_conventions/trace.rb,
lib/opentelemetry/semantic_conventions/version.rb,
lib/opentelemetry/semantic_conventions/resource.rb
Overview
The constants here ought to remain within major versions of this library. However, there risk with auto-generated code. The maintainers try to prevent constants disappearing, but we cannot gaurantee this. We strongly recommend that any constants you use in your code are exercised in your test suite to catch missing constants before release or production runtime.
OpenTelemetry semantic convention attribute names as constants. These are auto-generated from source YAML in the semantic-conventions repository.
Except for the Resource and Trace modules, constants in this namespace have been declared stable by the OpenTelemetry semantic conventions working group.
Defined Under Namespace
Constant Summary collapse
- SPEC_VERSION =
Version of the OpenTelemetry Semantic Conventions from which this library was generated.
'1.38.0'- VERSION =
Release version of this gem. May not match SPEC_VERSION until gem is released after a spec update.
'1.38.0'