Module: OpenTelemetry::SemConv::CONTAINER
- Defined in:
- lib/opentelemetry/semconv/container/attributes.rb
Attribute Names collapse
- CONTAINER_ID =
Note:
Stability Level: stable
Container ID. Usually a UUID, as for example used to identify Docker containers. The UUID might be abbreviated.
'container.id'- CONTAINER_IMAGE_NAME =
Note:
Stability Level: stable
Name of the image the container was built on.
'container.image.name'- CONTAINER_IMAGE_REPO_DIGESTS =
'container.image.repo_digests'- CONTAINER_IMAGE_TAGS =
Note:
Stability Level: stable
Container image tags. An example can be found in Docker Image Inspect. Should be only the
<tag>section of the full name for example fromregistry.example.com/my-org/my-image:<tag>. 'container.image.tags'