Module: OpenTelemetry::SemConv::Incubating::ASPNETCORE
- Defined in:
- lib/opentelemetry/semconv/incubating/aspnetcore/metrics.rb,
lib/opentelemetry/semconv/incubating/aspnetcore/attributes.rb
Metrics Names collapse
- ASPNETCORE_AUTHENTICATION_AUTHENTICATE_DURATION =
Note:
Stability Level: development
The authentication duration for a request.
Meter name:
Microsoft.AspNetCore.Authentication; Added in: ASP.NET Core 10.0 'aspnetcore.authentication.authenticate.duration'- ASPNETCORE_AUTHENTICATION_CHALLENGES =
Note:
Stability Level: development
The total number of times a scheme is challenged.
Meter name:
Microsoft.AspNetCore.Authentication; Added in: ASP.NET Core 10.0 'aspnetcore.authentication.challenges'- ASPNETCORE_AUTHENTICATION_FORBIDS =
Note:
Stability Level: development
The total number of times an authenticated user attempts to access a resource they are not permitted to access.
Meter name:
Microsoft.AspNetCore.Authentication; Added in: ASP.NET Core 10.0 'aspnetcore.authentication.forbids'- ASPNETCORE_AUTHENTICATION_SIGN_INS =
Note:
Stability Level: development
The total number of times a principal is signed in with a scheme.
Meter name:
Microsoft.AspNetCore.Authentication; Added in: ASP.NET Core 10.0 'aspnetcore.authentication.sign_ins'- ASPNETCORE_AUTHENTICATION_SIGN_OUTS =
Note:
Stability Level: development
The total number of times a principal is signed out with a scheme.
Meter name:
Microsoft.AspNetCore.Authentication; Added in: ASP.NET Core 10.0 'aspnetcore.authentication.sign_outs'- ASPNETCORE_AUTHORIZATION_ATTEMPTS =
Note:
Stability Level: development
The total number of authorization attempts.
Meter name:
Microsoft.AspNetCore.Authorization; Added in: ASP.NET Core 10.0 'aspnetcore.authorization.attempts'- ASPNETCORE_DIAGNOSTICS_EXCEPTIONS =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_DIAGNOSTICS_EXCEPTIONS.
Note:Stability Level: stable
Number of exceptions caught by exception handling middleware.
Meter name:
Microsoft.AspNetCore.Diagnostics; Added in: ASP.NET Core 8.0 'aspnetcore.diagnostics.exceptions'- ASPNETCORE_IDENTITY_SIGN_IN_AUTHENTICATE_DURATION =
Note:
Stability Level: development
The duration of authenticate attempts. The authenticate metrics is recorded by sign in methods such as PasswordSignInAsync and TwoFactorSignInAsync.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.authenticate.duration'- ASPNETCORE_IDENTITY_SIGN_IN_CHECK_PASSWORD_ATTEMPTS =
Note:
Stability Level: development
The total number of check password attempts. Checks that the account is in a state that can log in and that the password is valid using the UserManager.CheckPasswordAsync method.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.check_password_attempts'- ASPNETCORE_IDENTITY_SIGN_IN_SIGN_INS =
Note:
Stability Level: development
The total number of calls to sign in user principals.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.sign_ins'- ASPNETCORE_IDENTITY_SIGN_IN_SIGN_OUTS =
Note:
Stability Level: development
The total number of calls to sign out user principals.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.sign_outs'- ASPNETCORE_IDENTITY_SIGN_IN_TWO_FACTOR_CLIENTS_FORGOTTEN =
Note:
Stability Level: development
The total number of two factor clients forgotten.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.two_factor_clients_forgotten'- ASPNETCORE_IDENTITY_SIGN_IN_TWO_FACTOR_CLIENTS_REMEMBERED =
Note:
Stability Level: development
The total number of two factor clients remembered.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.sign_in.two_factor_clients_remembered'- ASPNETCORE_IDENTITY_USER_CHECK_PASSWORD_ATTEMPTS =
Note:
Stability Level: development
The number of check password attempts. Only checks whether the password is valid and not whether the user account is in a state that can log in.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.check_password_attempts'- ASPNETCORE_IDENTITY_USER_CREATE_DURATION =
Note:
Stability Level: development
The duration of user creation operations.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.create.duration'- ASPNETCORE_IDENTITY_USER_DELETE_DURATION =
Note:
Stability Level: development
The duration of user deletion operations.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.delete.duration'- ASPNETCORE_IDENTITY_USER_GENERATED_TOKENS =
Note:
Stability Level: development
The total number of token generations.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.generated_tokens'- ASPNETCORE_IDENTITY_USER_UPDATE_DURATION =
Note:
Stability Level: development
The duration of user update operations.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.update.duration'- ASPNETCORE_IDENTITY_USER_VERIFY_TOKEN_ATTEMPTS =
Note:
Stability Level: development
The total number of token verification attempts.
Meter name:
Microsoft.AspNetCore.Identity; Added in: ASP.NET Core 10.0 'aspnetcore.identity.user.verify_token_attempts'- ASPNETCORE_MEMORY_POOL_ALLOCATED =
Note:
Stability Level: development
Total number of bytes allocated by the memory pool. Allocation occurs when a memory rental request exceeds the available pooled memory.
Meter name:
Microsoft.AspNetCore.MemoryPool; Added in: ASP.NET Core 10.0 'aspnetcore.memory_pool.allocated'- ASPNETCORE_MEMORY_POOL_EVICTED =
Note:
Stability Level: development
Total number of bytes evicted from the memory pool. Eviction occurs when idle pooled memory is reclaimed.
Meter name:
Microsoft.AspNetCore.MemoryPool; Added in: ASP.NET Core 10.0 'aspnetcore.memory_pool.evicted'- ASPNETCORE_MEMORY_POOL_POOLED =
Note:
Stability Level: development
Number of bytes currently pooled and available for reuse.
Meter name:
Microsoft.AspNetCore.MemoryPool; Added in: ASP.NET Core 10.0 'aspnetcore.memory_pool.pooled'- ASPNETCORE_MEMORY_POOL_RENTED =
Note:
Stability Level: development
Total number of bytes rented from the memory pool.
Meter name:
Microsoft.AspNetCore.MemoryPool; Added in: ASP.NET Core 10.0 'aspnetcore.memory_pool.rented'- ASPNETCORE_RATE_LIMITING_ACTIVE_REQUEST_LEASES =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_ACTIVE_REQUEST_LEASES.
Note:Stability Level: stable
Number of requests that are currently active on the server that hold a rate limiting lease.
Meter name:
Microsoft.AspNetCore.RateLimiting; Added in: ASP.NET Core 8.0 'aspnetcore.rate_limiting.active_request_leases'- ASPNETCORE_RATE_LIMITING_QUEUED_REQUESTS =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_QUEUED_REQUESTS.
Note:Stability Level: stable
Number of requests that are currently queued, waiting to acquire a rate limiting lease.
Meter name:
Microsoft.AspNetCore.RateLimiting; Added in: ASP.NET Core 8.0 'aspnetcore.rate_limiting.queued_requests'- ASPNETCORE_RATE_LIMITING_REQUEST_TIME_IN_QUEUE =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_REQUEST_TIME_IN_QUEUE.
Note:Stability Level: stable
The time the request spent in a queue waiting to acquire a rate limiting lease.
Meter name:
Microsoft.AspNetCore.RateLimiting; Added in: ASP.NET Core 8.0 'aspnetcore.rate_limiting.request.time_in_queue'- ASPNETCORE_RATE_LIMITING_REQUEST_LEASE_DURATION =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_REQUEST_LEASE_DURATION.
Note:Stability Level: stable
The duration of rate limiting lease held by requests on the server.
Meter name:
Microsoft.AspNetCore.RateLimiting; Added in: ASP.NET Core 8.0 'aspnetcore.rate_limiting.request_lease.duration'- ASPNETCORE_RATE_LIMITING_REQUESTS =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_REQUESTS.
Note:Stability Level: stable
Number of requests that tried to acquire a rate limiting lease.
Requests could be:
- Rejected by global or endpoint rate limiting policies
- Canceled while waiting for the lease.
Meter name:
Microsoft.AspNetCore.RateLimiting; Added in: ASP.NET Core 8.0 'aspnetcore.rate_limiting.requests'- ASPNETCORE_ROUTING_MATCH_ATTEMPTS =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_ROUTING_MATCH_ATTEMPTS.
Note:Stability Level: stable
Number of requests that were attempted to be matched to an endpoint.
Meter name:
Microsoft.AspNetCore.Routing; Added in: ASP.NET Core 8.0 'aspnetcore.routing.match_attempts'
Attribute Names collapse
- ASPNETCORE_AUTHENTICATION_RESULT =
Note:
Stability Level: development
The result of the authentication operation.
'aspnetcore.authentication.result'- ASPNETCORE_AUTHENTICATION_SCHEME =
Note:
Stability Level: development
The identifier that names a particular authentication handler.
'aspnetcore.authentication.scheme'- ASPNETCORE_AUTHORIZATION_POLICY =
Note:
Stability Level: development
The name of the authorization policy.
'aspnetcore.authorization.policy'- ASPNETCORE_AUTHORIZATION_RESULT =
Note:
Stability Level: development
The result of calling the authorization service.
'aspnetcore.authorization.result'- ASPNETCORE_DIAGNOSTICS_EXCEPTION_RESULT =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_DIAGNOSTICS_EXCEPTION_RESULT.
Note:Stability Level: stable
ASP.NET Core exception middleware handling result.
'aspnetcore.diagnostics.exception.result'- ASPNETCORE_DIAGNOSTICS_HANDLER_TYPE =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_DIAGNOSTICS_HANDLER_TYPE.
Note:Stability Level: stable
Full type name of the
IExceptionHandlerimplementation that handled the exception. 'aspnetcore.diagnostics.handler.type'- ASPNETCORE_IDENTITY_ERROR_CODE =
Note:
Stability Level: development
The error code for a failed identity operation.
'aspnetcore.identity.error_code'- ASPNETCORE_IDENTITY_PASSWORD_CHECK_RESULT =
Note:
Stability Level: development
The result from checking the password.
'aspnetcore.identity.password_check_result'- ASPNETCORE_IDENTITY_RESULT =
Note:
Stability Level: development
The result of the identity operation.
'aspnetcore.identity.result'- ASPNETCORE_IDENTITY_SIGN_IN_RESULT =
Note:
Stability Level: development
Whether the sign in result was success or failure.
'aspnetcore.identity.sign_in.result'- ASPNETCORE_IDENTITY_SIGN_IN_TYPE =
Note:
Stability Level: development
The authentication type.
'aspnetcore.identity.sign_in.type'- ASPNETCORE_IDENTITY_TOKEN_PURPOSE =
Note:
Stability Level: development
What the token will be used for.
'aspnetcore.identity.token_purpose'- ASPNETCORE_IDENTITY_TOKEN_VERIFIED =
Note:
Stability Level: development
The result of token verification.
'aspnetcore.identity.token_verified'- ASPNETCORE_IDENTITY_USER_UPDATE_TYPE =
Note:
Stability Level: development
The user update type.
'aspnetcore.identity.user.update_type'- ASPNETCORE_IDENTITY_USER_TYPE =
Note:
Stability Level: development
The full name of the identity user type.
'aspnetcore.identity.user_type'- ASPNETCORE_MEMORY_POOL_OWNER =
Note:
Stability Level: development
The name of the library or subsystem using the memory pool instance.
'aspnetcore.memory_pool.owner'- ASPNETCORE_RATE_LIMITING_POLICY =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_POLICY.
Note:Stability Level: stable
Rate limiting policy name.
'aspnetcore.rate_limiting.policy'- ASPNETCORE_RATE_LIMITING_RESULT =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_RATE_LIMITING_RESULT.
Note:Stability Level: stable
Rate-limiting result, shows whether the lease was acquired or contains a rejection reason
'aspnetcore.rate_limiting.result'- ASPNETCORE_REQUEST_IS_UNHANDLED =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_REQUEST_IS_UNHANDLED.
Note:Stability Level: stable
Flag indicating if request was handled by the application pipeline.
'aspnetcore.request.is_unhandled'- ASPNETCORE_ROUTING_IS_FALLBACK =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_ROUTING_IS_FALLBACK.
Note:Stability Level: stable
A value that indicates whether the matched route is a fallback route.
'aspnetcore.routing.is_fallback'- ASPNETCORE_ROUTING_MATCH_STATUS =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_ROUTING_MATCH_STATUS.
Note:Stability Level: stable
Match result - success or failure
'aspnetcore.routing.match_status'- ASPNETCORE_SIGN_IN_IS_PERSISTENT =
Note:
Stability Level: development
A flag indicating whether the sign in is persistent.
'aspnetcore.sign_in.is_persistent'- ASPNETCORE_USER_IS_AUTHENTICATED =
Deprecated.
Now available in the stable namespace at ASPNETCORE::ASPNETCORE_USER_IS_AUTHENTICATED.
Note:Stability Level: stable
A value that indicates whether the user is authenticated.
'aspnetcore.user.is_authenticated'