Module: OpenTelemetry::SemConv::Incubating::CICD
- Defined in:
- lib/opentelemetry/semconv/incubating/cicd/metrics.rb,
lib/opentelemetry/semconv/incubating/cicd/attributes.rb
Metrics Names collapse
- CICD_PIPELINE_RUN_ACTIVE =
Note:
Stability Level: development
The number of pipeline runs currently active in the system by state.
'cicd.pipeline.run.active'- CICD_PIPELINE_RUN_DURATION =
Note:
Stability Level: development
Duration of a pipeline run grouped by pipeline, state and result.
'cicd.pipeline.run.duration'- CICD_PIPELINE_RUN_ERRORS =
Note:
Stability Level: development
The number of errors encountered in pipeline runs (eg. compile, test failures).
There might be errors in a pipeline run that are non fatal (eg. they are suppressed) or in a parallel stage multiple stages could have a fatal error. This means that this error count might not be the same as the count of metric
cicd.pipeline.run.durationwith run resultfailure. 'cicd.pipeline.run.errors'- CICD_SYSTEM_ERRORS =
Note:
Stability Level: development
The number of errors in a component of the CICD system (eg. controller, scheduler, agent).
Errors in pipeline run execution are explicitly excluded. Ie a test failure is not counted in this metric.
'cicd.system.errors'- CICD_WORKER_COUNT =
Note:
Stability Level: development
The number of workers on the CICD system by state.
'cicd.worker.count'
Attribute Names collapse
- CICD_PIPELINE_ACTION_NAME =
Note:
Stability Level: development
The kind of action a pipeline run is performing.
'cicd.pipeline.action.name'- CICD_PIPELINE_NAME =
Note:
Stability Level: development
The human readable name of the pipeline within a CI/CD system.
'cicd.pipeline.name'- CICD_PIPELINE_RESULT =
Note:
Stability Level: development
The result of a pipeline run.
'cicd.pipeline.result'- CICD_PIPELINE_RUN_ID =
Note:
Stability Level: development
The unique identifier of a pipeline run within a CI/CD system.
'cicd.pipeline.run.id'- CICD_PIPELINE_RUN_STATE =
Note:
Stability Level: development
The pipeline run goes through these states during its lifecycle.
'cicd.pipeline.run.state'- CICD_PIPELINE_RUN_URL_FULL =
Note:
Stability Level: development
The URL of the pipeline run, providing the complete address in order to locate and identify the pipeline run.
'cicd.pipeline.run.url.full'- CICD_PIPELINE_TASK_NAME =
Note:
Stability Level: development
The human readable name of a task within a pipeline. Task here most closely aligns with a computing process in a pipeline. Other terms for tasks include commands, steps, and procedures.
'cicd.pipeline.task.name'- CICD_PIPELINE_TASK_RUN_ID =
Note:
Stability Level: development
The unique identifier of a task run within a pipeline.
For a given pipeline run and task, the
cicd.pipeline.task.run.idMUST be unique within that run. For the same task across different runs of the same pipeline, thecicd.pipeline.task.run.idMAY remain the same, enabling correlation ofcicd.pipeline.task.run.resultvalues across multiple pipeline runs. 'cicd.pipeline.task.run.id'- CICD_PIPELINE_TASK_RUN_RESULT =
Note:
Stability Level: development
The result of a task run.
'cicd.pipeline.task.run.result'- CICD_PIPELINE_TASK_RUN_URL_FULL =
Note:
Stability Level: development
The URL of the pipeline task run, providing the complete address in order to locate and identify the pipeline task run.
'cicd.pipeline.task.run.url.full'- CICD_PIPELINE_TASK_TYPE =
Note:
Stability Level: development
The type of the task within a pipeline.
'cicd.pipeline.task.type'- CICD_SYSTEM_COMPONENT =
Note:
Stability Level: development
The name of a component of the CICD system.
'cicd.system.component'- CICD_WORKER_ID =
Note:
Stability Level: development
The unique identifier of a worker within a CICD system.
'cicd.worker.id'- CICD_WORKER_NAME =
Note:
Stability Level: development
The name of a worker within a CICD system.
'cicd.worker.name'- CICD_WORKER_STATE =
Note:
Stability Level: development
The state of a CICD worker / agent.
'cicd.worker.state'- CICD_WORKER_URL_FULL =
Note:
Stability Level: development
The URL of the worker, providing the complete address in order to locate and identify the worker.
'cicd.worker.url.full'