Module: OpenTelemetry::SemConv::Incubating::JSONRPC
- Defined in:
- lib/opentelemetry/semconv/incubating/jsonrpc/attributes.rb
Attribute Names collapse
- JSONRPC_PROTOCOL_VERSION =
Note:
Stability Level: development
Protocol version, as specified in the
jsonrpcproperty of the request and its corresponding response. 'jsonrpc.protocol.version'- JSONRPC_REQUEST_ID =
Note:
Stability Level: development
A string representation of the
idproperty of the request and its corresponding response.Under the JSON-RPC specification, the
idproperty may be a string, number, null, or omitted entirely. When omitted, the request is treated as a notification. Usingnullis not equivalent to omitting theid, but it is discouraged. Instrumentations SHOULD NOT capture this attribute when theidisnullor omitted. 'jsonrpc.request.id'