Module: OpenTelemetry::SemConv::Incubating::OPENSHIFT
- Defined in:
- lib/opentelemetry/semconv/incubating/openshift/metrics.rb,
lib/opentelemetry/semconv/incubating/openshift/attributes.rb
Metrics Names collapse
- OPENSHIFT_CLUSTERQUOTA_CPU_LIMIT_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.cpu.limit.hard'- OPENSHIFT_CLUSTERQUOTA_CPU_LIMIT_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.cpu.limit.used'- OPENSHIFT_CLUSTERQUOTA_CPU_REQUEST_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.cpu.request.hard'- OPENSHIFT_CLUSTERQUOTA_CPU_REQUEST_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.cpu.request.used'- OPENSHIFT_CLUSTERQUOTA_EPHEMERAL_STORAGE_LIMIT_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.ephemeral_storage.limit.hard'- OPENSHIFT_CLUSTERQUOTA_EPHEMERAL_STORAGE_LIMIT_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.ephemeral_storage.limit.used'- OPENSHIFT_CLUSTERQUOTA_EPHEMERAL_STORAGE_REQUEST_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.ephemeral_storage.request.hard'- OPENSHIFT_CLUSTERQUOTA_EPHEMERAL_STORAGE_REQUEST_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.ephemeral_storage.request.used'- OPENSHIFT_CLUSTERQUOTA_HUGEPAGE_COUNT_REQUEST_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.hugepage_count.request.hard'- OPENSHIFT_CLUSTERQUOTA_HUGEPAGE_COUNT_REQUEST_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.hugepage_count.request.used'- OPENSHIFT_CLUSTERQUOTA_MEMORY_LIMIT_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.memory.limit.hard'- OPENSHIFT_CLUSTERQUOTA_MEMORY_LIMIT_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.memory.limit.used'- OPENSHIFT_CLUSTERQUOTA_MEMORY_REQUEST_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.memory.request.hard'- OPENSHIFT_CLUSTERQUOTA_MEMORY_REQUEST_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.memory.request.used'- OPENSHIFT_CLUSTERQUOTA_OBJECT_COUNT_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.object_count.hard'- OPENSHIFT_CLUSTERQUOTA_OBJECT_COUNT_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota. 'openshift.clusterquota.object_count.used'- OPENSHIFT_CLUSTERQUOTA_PERSISTENTVOLUMECLAIM_COUNT_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota.The
k8s.storageclass.nameshould be required when a resource quota is defined for a specific storage class. 'openshift.clusterquota.persistentvolumeclaim_count.hard'- OPENSHIFT_CLUSTERQUOTA_PERSISTENTVOLUMECLAIM_COUNT_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota.The
k8s.storageclass.nameshould be required when a resource quota is defined for a specific storage class. 'openshift.clusterquota.persistentvolumeclaim_count.used'- OPENSHIFT_CLUSTERQUOTA_STORAGE_REQUEST_HARD =
Note:
Stability Level: development
The enforced hard limit of the resource across all projects.
This metric is retrieved from the
Status.Total.Hardfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota.The
k8s.storageclass.nameshould be required when a resource quota is defined for a specific storage class. 'openshift.clusterquota.storage.request.hard'- OPENSHIFT_CLUSTERQUOTA_STORAGE_REQUEST_USED =
Note:
Stability Level: development
The current observed total usage of the resource across all projects.
This metric is retrieved from the
Status.Total.Usedfield of the K8s ResourceQuotaStatus of the ClusterResourceQuota.The
k8s.storageclass.nameshould be required when a resource quota is defined for a specific storage class. 'openshift.clusterquota.storage.request.used'
Attribute Names collapse
- OPENSHIFT_CLUSTERQUOTA_NAME =
Note:
Stability Level: development
The name of the cluster quota.
'openshift.clusterquota.name'- OPENSHIFT_CLUSTERQUOTA_UID =
Note:
Stability Level: development
The UID of the cluster quota.
'openshift.clusterquota.uid'