Module: OpenTelemetry::SemConv::Incubating::PPROF
- Defined in:
- lib/opentelemetry/semconv/incubating/pprof/attributes.rb
Attribute Names collapse
- PPROF_LOCATION_IS_FOLDED =
Note:
Stability Level: development
Provides an indication that multiple symbols map to this location's address, for example due to identical code folding by the linker. In that case the line information represents one of the multiple symbols. This field must be recomputed when the symbolization state of the profile changes.
'pprof.location.is_folded'- PPROF_MAPPING_HAS_FILENAMES =
Note:
Stability Level: development
Indicates that there are filenames related to this mapping.
'pprof.mapping.has_filenames'- PPROF_MAPPING_HAS_FUNCTIONS =
Note:
Stability Level: development
Indicates that there are functions related to this mapping.
'pprof.mapping.has_functions'- PPROF_MAPPING_HAS_INLINE_FRAMES =
Note:
Stability Level: development
Indicates that there are inline frames related to this mapping.
'pprof.mapping.has_inline_frames'- PPROF_MAPPING_HAS_LINE_NUMBERS =
Note:
Stability Level: development
Indicates that there are line numbers related to this mapping.
'pprof.mapping.has_line_numbers'- PPROF_PROFILE_COMMENT =
Note:
Stability Level: development
Free-form text associated with the profile. This field should not be used to store any machine-readable information, it is only for human-friendly content.
'pprof.profile.comment'