Module: OpenTelemetry::SemConv::Incubating::THREAD
- Defined in:
- lib/opentelemetry/semconv/incubating/thread/attributes.rb
Attribute Names collapse
- THREAD_ID =
Note:
Stability Level: development
Current "managed" thread ID (as opposed to OS thread ID).
Examples of where the value can be extracted from:
Language or platform Source JVM Thread.currentThread().threadId().NET Thread.CurrentThread.ManagedThreadIdPython threading.current_thread().identRuby Thread.current.object_idC++ std::this_thread::get_id()Erlang erlang:self() 'thread.id'- THREAD_NAME =
Note:
Stability Level: development
Current thread name.
Examples of where the value can be extracted from:
Language or platform Source JVM Thread.currentThread().getName().NET Thread.CurrentThread.NamePython threading.current_thread().nameRuby Thread.current.nameErlang erlang:process_info(self(), registered_name) 'thread.name'