Module: OpenTelemetry::SemConv::OTEL
- Defined in:
- lib/opentelemetry/semconv/otel/attributes.rb
Attribute Names collapse
- OTEL_EVENT_NAME =
Note:
Stability Level: stable
Identifies the class / type of event.
This attribute SHOULD be used by non-OTLP exporters when destination does not support
EventNameor equivalent field. This attribute MAY be used by applications using existing logging libraries so that it can be used to set theEventNamefield by Collector or SDK components. 'otel.event.name'- OTEL_SCOPE_NAME =
Note:
Stability Level: stable
The name of the instrumentation scope - (
InstrumentationScope.Namein OTLP). 'otel.scope.name'- OTEL_SCOPE_VERSION =
Note:
Stability Level: stable
The version of the instrumentation scope - (
InstrumentationScope.Versionin OTLP). 'otel.scope.version'- OTEL_STATUS_CODE =
Note:
Stability Level: stable
Name of the code, either "OK" or "ERROR". MUST NOT be set if the status code is UNSET.
'otel.status_code'- OTEL_STATUS_DESCRIPTION =
Note:
Stability Level: stable
Description of the Status if it has a value, otherwise not set.
'otel.status_description'