Module: OpenTelemetry::SemConv::OTEL

Defined in:
lib/opentelemetry/semconv/otel/attributes.rb

Attribute Names collapse

OTEL_SCOPE_NAME =
Note:

Stability Level: stable

The name of the instrumentation scope - (InstrumentationScope.Name in OTLP).

'otel.scope.name'
OTEL_SCOPE_VERSION =
Note:

Stability Level: stable

The version of the instrumentation scope - (InstrumentationScope.Version in OTLP).

'otel.scope.version'
OTEL_STATUS_CODE =
Note:

Stability Level: stable

Name of the code, either "OK" or "ERROR". MUST NOT be set if the status code is UNSET.

'otel.status_code'
OTEL_STATUS_DESCRIPTION =
Note:

Stability Level: stable

Description of the Status if it has a value, otherwise not set.

'otel.status_description'